from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.connection_remote_model_connection_status import (
    ConnectionRemoteModelConnectionStatus,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="ConnectionRemoteModel")


@attr.s(auto_attribs=True)
class ConnectionRemoteModel:
    """Connection status remote management

    Attributes:
        connection_status (Union[Unset, ConnectionRemoteModelConnectionStatus]): Connection status
        error_message (Union[Unset, str]): Error message
    """

    connection_status: Union[Unset, ConnectionRemoteModelConnectionStatus] = UNSET
    error_message: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection_status: Union[Unset, str] = UNSET
        if not isinstance(self.connection_status, Unset):
            connection_status = self.connection_status.value

        error_message = self.error_message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection_status is not UNSET:
            field_dict["connectionStatus"] = connection_status
        if error_message is not UNSET:
            field_dict["errorMessage"] = error_message

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _connection_status = d.pop("connectionStatus", UNSET)
        connection_status: Union[Unset, ConnectionRemoteModelConnectionStatus]
        if isinstance(_connection_status, Unset):
            connection_status = UNSET
        else:
            connection_status = ConnectionRemoteModelConnectionStatus(
                _connection_status
            )

        error_message = d.pop("errorMessage", UNSET)

        connection_remote_model = cls(
            connection_status=connection_status,
            error_message=error_message,
        )

        connection_remote_model.additional_properties = d
        return connection_remote_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_daily_partitioned_check_categories_spec_comparisons import (
        TableDailyPartitionedCheckCategoriesSpecComparisons,
    )
    from ..models.table_daily_partitioned_check_categories_spec_custom import (
        TableDailyPartitionedCheckCategoriesSpecCustom,
    )
    from ..models.table_sql_daily_partitioned_checks_spec import (
        TableSqlDailyPartitionedChecksSpec,
    )
    from ..models.table_timeliness_daily_partitioned_checks_spec import (
        TableTimelinessDailyPartitionedChecksSpec,
    )
    from ..models.table_volume_daily_partitioned_checks_spec import (
        TableVolumeDailyPartitionedChecksSpec,
    )


T = TypeVar("T", bound="TableDailyPartitionedCheckCategoriesSpec")


@attr.s(auto_attribs=True)
class TableDailyPartitionedCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, TableDailyPartitionedCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys are
            check names.
        volume (Union[Unset, TableVolumeDailyPartitionedChecksSpec]):
        timeliness (Union[Unset, TableTimelinessDailyPartitionedChecksSpec]):
        sql (Union[Unset, TableSqlDailyPartitionedChecksSpec]):
        comparisons (Union[Unset, TableDailyPartitionedCheckCategoriesSpecComparisons]): Dictionary of configuration of
            checks for table comparisons. The key that identifies each comparison must match the name of a data comparison
            that is configured on the parent table.
    """

    custom: Union[Unset, "TableDailyPartitionedCheckCategoriesSpecCustom"] = UNSET
    volume: Union[Unset, "TableVolumeDailyPartitionedChecksSpec"] = UNSET
    timeliness: Union[Unset, "TableTimelinessDailyPartitionedChecksSpec"] = UNSET
    sql: Union[Unset, "TableSqlDailyPartitionedChecksSpec"] = UNSET
    comparisons: Union[
        Unset, "TableDailyPartitionedCheckCategoriesSpecComparisons"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        volume: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.volume, Unset):
            volume = self.volume.to_dict()

        timeliness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.timeliness, Unset):
            timeliness = self.timeliness.to_dict()

        sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sql, Unset):
            sql = self.sql.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if volume is not UNSET:
            field_dict["volume"] = volume
        if timeliness is not UNSET:
            field_dict["timeliness"] = timeliness
        if sql is not UNSET:
            field_dict["sql"] = sql
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_daily_partitioned_check_categories_spec_comparisons import (
            TableDailyPartitionedCheckCategoriesSpecComparisons,
        )
        from ..models.table_daily_partitioned_check_categories_spec_custom import (
            TableDailyPartitionedCheckCategoriesSpecCustom,
        )
        from ..models.table_sql_daily_partitioned_checks_spec import (
            TableSqlDailyPartitionedChecksSpec,
        )
        from ..models.table_timeliness_daily_partitioned_checks_spec import (
            TableTimelinessDailyPartitionedChecksSpec,
        )
        from ..models.table_volume_daily_partitioned_checks_spec import (
            TableVolumeDailyPartitionedChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, TableDailyPartitionedCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = TableDailyPartitionedCheckCategoriesSpecCustom.from_dict(_custom)

        _volume = d.pop("volume", UNSET)
        volume: Union[Unset, TableVolumeDailyPartitionedChecksSpec]
        if isinstance(_volume, Unset):
            volume = UNSET
        else:
            volume = TableVolumeDailyPartitionedChecksSpec.from_dict(_volume)

        _timeliness = d.pop("timeliness", UNSET)
        timeliness: Union[Unset, TableTimelinessDailyPartitionedChecksSpec]
        if isinstance(_timeliness, Unset):
            timeliness = UNSET
        else:
            timeliness = TableTimelinessDailyPartitionedChecksSpec.from_dict(
                _timeliness
            )

        _sql = d.pop("sql", UNSET)
        sql: Union[Unset, TableSqlDailyPartitionedChecksSpec]
        if isinstance(_sql, Unset):
            sql = UNSET
        else:
            sql = TableSqlDailyPartitionedChecksSpec.from_dict(_sql)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, TableDailyPartitionedCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = TableDailyPartitionedCheckCategoriesSpecComparisons.from_dict(
                _comparisons
            )

        table_daily_partitioned_check_categories_spec = cls(
            custom=custom,
            volume=volume,
            timeliness=timeliness,
            sql=sql,
            comparisons=comparisons,
        )

        table_daily_partitioned_check_categories_spec.additional_properties = d
        return table_daily_partitioned_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.connection_spec_provider_type import ConnectionSpecProviderType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.big_query_parameters_spec import BigQueryParametersSpec
    from ..models.comment_spec import CommentSpec
    from ..models.connection_incident_grouping_spec import (
        ConnectionIncidentGroupingSpec,
    )
    from ..models.data_grouping_configuration_spec import DataGroupingConfigurationSpec
    from ..models.mysql_parameters_spec import MysqlParametersSpec
    from ..models.oracle_parameters_spec import OracleParametersSpec
    from ..models.postgresql_parameters_spec import PostgresqlParametersSpec
    from ..models.recurring_schedules_spec import RecurringSchedulesSpec
    from ..models.redshift_parameters_spec import RedshiftParametersSpec
    from ..models.snowflake_parameters_spec import SnowflakeParametersSpec
    from ..models.sql_server_parameters_spec import SqlServerParametersSpec


T = TypeVar("T", bound="ConnectionSpec")


@attr.s(auto_attribs=True)
class ConnectionSpec:
    """
    Attributes:
        provider_type (Union[Unset, ConnectionSpecProviderType]): Database provider type (required).
        bigquery (Union[Unset, BigQueryParametersSpec]):
        snowflake (Union[Unset, SnowflakeParametersSpec]):
        postgresql (Union[Unset, PostgresqlParametersSpec]):
        redshift (Union[Unset, RedshiftParametersSpec]):
        sqlserver (Union[Unset, SqlServerParametersSpec]):
        mysql (Union[Unset, MysqlParametersSpec]):
        oracle (Union[Unset, OracleParametersSpec]):
        parallel_runs_limit (Union[Unset, int]): The concurrency limit for the maximum number of parallel SQL queries
            executed on this connection.
        default_grouping_configuration (Union[Unset, DataGroupingConfigurationSpec]):
        schedules (Union[Unset, RecurringSchedulesSpec]):
        incident_grouping (Union[Unset, ConnectionIncidentGroupingSpec]):
        comments (Union[Unset, List['CommentSpec']]): Comments for change tracking. Please put comments in this
            collection because YAML comments may be removed when the YAML file is modified by the tool (serialization and
            deserialization will remove non tracked comments).
        labels (Union[Unset, List[str]]): Custom labels that were assigned to the connection. Labels are used for
            searching for tables when filtered data quality checks are executed.
    """

    provider_type: Union[Unset, ConnectionSpecProviderType] = UNSET
    bigquery: Union[Unset, "BigQueryParametersSpec"] = UNSET
    snowflake: Union[Unset, "SnowflakeParametersSpec"] = UNSET
    postgresql: Union[Unset, "PostgresqlParametersSpec"] = UNSET
    redshift: Union[Unset, "RedshiftParametersSpec"] = UNSET
    sqlserver: Union[Unset, "SqlServerParametersSpec"] = UNSET
    mysql: Union[Unset, "MysqlParametersSpec"] = UNSET
    oracle: Union[Unset, "OracleParametersSpec"] = UNSET
    parallel_runs_limit: Union[Unset, int] = UNSET
    default_grouping_configuration: Union[
        Unset, "DataGroupingConfigurationSpec"
    ] = UNSET
    schedules: Union[Unset, "RecurringSchedulesSpec"] = UNSET
    incident_grouping: Union[Unset, "ConnectionIncidentGroupingSpec"] = UNSET
    comments: Union[Unset, List["CommentSpec"]] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provider_type: Union[Unset, str] = UNSET
        if not isinstance(self.provider_type, Unset):
            provider_type = self.provider_type.value

        bigquery: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bigquery, Unset):
            bigquery = self.bigquery.to_dict()

        snowflake: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.snowflake, Unset):
            snowflake = self.snowflake.to_dict()

        postgresql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.postgresql, Unset):
            postgresql = self.postgresql.to_dict()

        redshift: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.redshift, Unset):
            redshift = self.redshift.to_dict()

        sqlserver: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.sqlserver, Unset):
            sqlserver = self.sqlserver.to_dict()

        mysql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.mysql, Unset):
            mysql = self.mysql.to_dict()

        oracle: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.oracle, Unset):
            oracle = self.oracle.to_dict()

        parallel_runs_limit = self.parallel_runs_limit
        default_grouping_configuration: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.default_grouping_configuration, Unset):
            default_grouping_configuration = (
                self.default_grouping_configuration.to_dict()
            )

        schedules: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schedules, Unset):
            schedules = self.schedules.to_dict()

        incident_grouping: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.incident_grouping, Unset):
            incident_grouping = self.incident_grouping.to_dict()

        comments: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if provider_type is not UNSET:
            field_dict["provider_type"] = provider_type
        if bigquery is not UNSET:
            field_dict["bigquery"] = bigquery
        if snowflake is not UNSET:
            field_dict["snowflake"] = snowflake
        if postgresql is not UNSET:
            field_dict["postgresql"] = postgresql
        if redshift is not UNSET:
            field_dict["redshift"] = redshift
        if sqlserver is not UNSET:
            field_dict["sqlserver"] = sqlserver
        if mysql is not UNSET:
            field_dict["mysql"] = mysql
        if oracle is not UNSET:
            field_dict["oracle"] = oracle
        if parallel_runs_limit is not UNSET:
            field_dict["parallel_runs_limit"] = parallel_runs_limit
        if default_grouping_configuration is not UNSET:
            field_dict[
                "default_grouping_configuration"
            ] = default_grouping_configuration
        if schedules is not UNSET:
            field_dict["schedules"] = schedules
        if incident_grouping is not UNSET:
            field_dict["incident_grouping"] = incident_grouping
        if comments is not UNSET:
            field_dict["comments"] = comments
        if labels is not UNSET:
            field_dict["labels"] = labels

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.big_query_parameters_spec import BigQueryParametersSpec
        from ..models.comment_spec import CommentSpec
        from ..models.connection_incident_grouping_spec import (
            ConnectionIncidentGroupingSpec,
        )
        from ..models.data_grouping_configuration_spec import (
            DataGroupingConfigurationSpec,
        )
        from ..models.mysql_parameters_spec import MysqlParametersSpec
        from ..models.oracle_parameters_spec import OracleParametersSpec
        from ..models.postgresql_parameters_spec import PostgresqlParametersSpec
        from ..models.recurring_schedules_spec import RecurringSchedulesSpec
        from ..models.redshift_parameters_spec import RedshiftParametersSpec
        from ..models.snowflake_parameters_spec import SnowflakeParametersSpec
        from ..models.sql_server_parameters_spec import SqlServerParametersSpec

        d = src_dict.copy()
        _provider_type = d.pop("provider_type", UNSET)
        provider_type: Union[Unset, ConnectionSpecProviderType]
        if isinstance(_provider_type, Unset):
            provider_type = UNSET
        else:
            provider_type = ConnectionSpecProviderType(_provider_type)

        _bigquery = d.pop("bigquery", UNSET)
        bigquery: Union[Unset, BigQueryParametersSpec]
        if isinstance(_bigquery, Unset):
            bigquery = UNSET
        else:
            bigquery = BigQueryParametersSpec.from_dict(_bigquery)

        _snowflake = d.pop("snowflake", UNSET)
        snowflake: Union[Unset, SnowflakeParametersSpec]
        if isinstance(_snowflake, Unset):
            snowflake = UNSET
        else:
            snowflake = SnowflakeParametersSpec.from_dict(_snowflake)

        _postgresql = d.pop("postgresql", UNSET)
        postgresql: Union[Unset, PostgresqlParametersSpec]
        if isinstance(_postgresql, Unset):
            postgresql = UNSET
        else:
            postgresql = PostgresqlParametersSpec.from_dict(_postgresql)

        _redshift = d.pop("redshift", UNSET)
        redshift: Union[Unset, RedshiftParametersSpec]
        if isinstance(_redshift, Unset):
            redshift = UNSET
        else:
            redshift = RedshiftParametersSpec.from_dict(_redshift)

        _sqlserver = d.pop("sqlserver", UNSET)
        sqlserver: Union[Unset, SqlServerParametersSpec]
        if isinstance(_sqlserver, Unset):
            sqlserver = UNSET
        else:
            sqlserver = SqlServerParametersSpec.from_dict(_sqlserver)

        _mysql = d.pop("mysql", UNSET)
        mysql: Union[Unset, MysqlParametersSpec]
        if isinstance(_mysql, Unset):
            mysql = UNSET
        else:
            mysql = MysqlParametersSpec.from_dict(_mysql)

        _oracle = d.pop("oracle", UNSET)
        oracle: Union[Unset, OracleParametersSpec]
        if isinstance(_oracle, Unset):
            oracle = UNSET
        else:
            oracle = OracleParametersSpec.from_dict(_oracle)

        parallel_runs_limit = d.pop("parallel_runs_limit", UNSET)

        _default_grouping_configuration = d.pop("default_grouping_configuration", UNSET)
        default_grouping_configuration: Union[Unset, DataGroupingConfigurationSpec]
        if isinstance(_default_grouping_configuration, Unset):
            default_grouping_configuration = UNSET
        else:
            default_grouping_configuration = DataGroupingConfigurationSpec.from_dict(
                _default_grouping_configuration
            )

        _schedules = d.pop("schedules", UNSET)
        schedules: Union[Unset, RecurringSchedulesSpec]
        if isinstance(_schedules, Unset):
            schedules = UNSET
        else:
            schedules = RecurringSchedulesSpec.from_dict(_schedules)

        _incident_grouping = d.pop("incident_grouping", UNSET)
        incident_grouping: Union[Unset, ConnectionIncidentGroupingSpec]
        if isinstance(_incident_grouping, Unset):
            incident_grouping = UNSET
        else:
            incident_grouping = ConnectionIncidentGroupingSpec.from_dict(
                _incident_grouping
            )

        comments = []
        _comments = d.pop("comments", UNSET)
        for comments_item_data in _comments or []:
            comments_item = CommentSpec.from_dict(comments_item_data)

            comments.append(comments_item)

        labels = cast(List[str], d.pop("labels", UNSET))

        connection_spec = cls(
            provider_type=provider_type,
            bigquery=bigquery,
            snowflake=snowflake,
            postgresql=postgresql,
            redshift=redshift,
            sqlserver=sqlserver,
            mysql=mysql,
            oracle=oracle,
            parallel_runs_limit=parallel_runs_limit,
            default_grouping_configuration=default_grouping_configuration,
            schedules=schedules,
            incident_grouping=incident_grouping,
            comments=comments,
            labels=labels,
        )

        connection_spec.additional_properties = d
        return connection_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.check_container_type_model_check_time_scale import (
    CheckContainerTypeModelCheckTimeScale,
)
from ..models.check_container_type_model_check_type import (
    CheckContainerTypeModelCheckType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckContainerTypeModel")


@attr.s(auto_attribs=True)
class CheckContainerTypeModel:
    """Model identifying the check type and timescale of checks belonging to a container.

    Attributes:
        check_type (Union[Unset, CheckContainerTypeModelCheckType]): Check type.
        check_time_scale (Union[Unset, CheckContainerTypeModelCheckTimeScale]): Check timescale.
    """

    check_type: Union[Unset, CheckContainerTypeModelCheckType] = UNSET
    check_time_scale: Union[Unset, CheckContainerTypeModelCheckTimeScale] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        check_time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.check_time_scale, Unset):
            check_time_scale = self.check_time_scale.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if check_type is not UNSET:
            field_dict["check_type"] = check_type
        if check_time_scale is not UNSET:
            field_dict["check_time_scale"] = check_time_scale

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _check_type = d.pop("check_type", UNSET)
        check_type: Union[Unset, CheckContainerTypeModelCheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckContainerTypeModelCheckType(_check_type)

        _check_time_scale = d.pop("check_time_scale", UNSET)
        check_time_scale: Union[Unset, CheckContainerTypeModelCheckTimeScale]
        if isinstance(_check_time_scale, Unset):
            check_time_scale = UNSET
        else:
            check_time_scale = CheckContainerTypeModelCheckTimeScale(_check_time_scale)

        check_container_type_model = cls(
            check_type=check_type,
            check_time_scale=check_time_scale,
        )

        check_container_type_model.additional_properties = d
        return check_container_type_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.provider_sensor_basic_model_provider_type import (
    ProviderSensorBasicModelProviderType,
)
from ..types import UNSET, Unset

T = TypeVar("T", bound="ProviderSensorBasicModel")


@attr.s(auto_attribs=True)
class ProviderSensorBasicModel:
    """Provider sensor basic model

    Attributes:
        provider_type (Union[Unset, ProviderSensorBasicModelProviderType]): Provider type.
        custom (Union[Unset, bool]): This connection specific template is a custom sensor template or was customized by
            the user.
        built_in (Union[Unset, bool]): This connection specific template is provided with DQO as a built-in sensor.
    """

    provider_type: Union[Unset, ProviderSensorBasicModelProviderType] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provider_type: Union[Unset, str] = UNSET
        if not isinstance(self.provider_type, Unset):
            provider_type = self.provider_type.value

        custom = self.custom
        built_in = self.built_in

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if provider_type is not UNSET:
            field_dict["provider_type"] = provider_type
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["built_in"] = built_in

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _provider_type = d.pop("provider_type", UNSET)
        provider_type: Union[Unset, ProviderSensorBasicModelProviderType]
        if isinstance(_provider_type, Unset):
            provider_type = UNSET
        else:
            provider_type = ProviderSensorBasicModelProviderType(_provider_type)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("built_in", UNSET)

        provider_sensor_basic_model = cls(
            provider_type=provider_type,
            custom=custom,
            built_in=built_in,
        )

        provider_sensor_basic_model.additional_properties = d
        return provider_sensor_basic_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.provider_sensor_model_provider_type import ProviderSensorModelProviderType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.provider_sensor_definition_spec import ProviderSensorDefinitionSpec


T = TypeVar("T", bound="ProviderSensorModel")


@attr.s(auto_attribs=True)
class ProviderSensorModel:
    """Provider sensor model

    Attributes:
        provider_type (Union[Unset, ProviderSensorModelProviderType]): Provider type.
        provider_sensor_definition_spec (Union[Unset, ProviderSensorDefinitionSpec]):
        sql_template (Union[Unset, str]): Provider Sql template
        custom (Union[Unset, bool]): Whether the provider sensor is a User Home provider sensor
        built_in (Union[Unset, bool]): This is a DQO built-in provider sensor, whose parameters cannot be changed.
    """

    provider_type: Union[Unset, ProviderSensorModelProviderType] = UNSET
    provider_sensor_definition_spec: Union[
        Unset, "ProviderSensorDefinitionSpec"
    ] = UNSET
    sql_template: Union[Unset, str] = UNSET
    custom: Union[Unset, bool] = UNSET
    built_in: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        provider_type: Union[Unset, str] = UNSET
        if not isinstance(self.provider_type, Unset):
            provider_type = self.provider_type.value

        provider_sensor_definition_spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.provider_sensor_definition_spec, Unset):
            provider_sensor_definition_spec = (
                self.provider_sensor_definition_spec.to_dict()
            )

        sql_template = self.sql_template
        custom = self.custom
        built_in = self.built_in

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if provider_type is not UNSET:
            field_dict["providerType"] = provider_type
        if provider_sensor_definition_spec is not UNSET:
            field_dict["providerSensorDefinitionSpec"] = provider_sensor_definition_spec
        if sql_template is not UNSET:
            field_dict["sqlTemplate"] = sql_template
        if custom is not UNSET:
            field_dict["custom"] = custom
        if built_in is not UNSET:
            field_dict["builtIn"] = built_in

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.provider_sensor_definition_spec import (
            ProviderSensorDefinitionSpec,
        )

        d = src_dict.copy()
        _provider_type = d.pop("providerType", UNSET)
        provider_type: Union[Unset, ProviderSensorModelProviderType]
        if isinstance(_provider_type, Unset):
            provider_type = UNSET
        else:
            provider_type = ProviderSensorModelProviderType(_provider_type)

        _provider_sensor_definition_spec = d.pop("providerSensorDefinitionSpec", UNSET)
        provider_sensor_definition_spec: Union[Unset, ProviderSensorDefinitionSpec]
        if isinstance(_provider_sensor_definition_spec, Unset):
            provider_sensor_definition_spec = UNSET
        else:
            provider_sensor_definition_spec = ProviderSensorDefinitionSpec.from_dict(
                _provider_sensor_definition_spec
            )

        sql_template = d.pop("sqlTemplate", UNSET)

        custom = d.pop("custom", UNSET)

        built_in = d.pop("builtIn", UNSET)

        provider_sensor_model = cls(
            provider_type=provider_type,
            provider_sensor_definition_spec=provider_sensor_definition_spec,
            sql_template=sql_template,
            custom=custom,
            built_in=built_in,
        )

        provider_sensor_model.additional_properties = d
        return provider_sensor_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.collect_statistics_on_table_queue_job_parameters_data_scope import (
    CollectStatisticsOnTableQueueJobParametersDataScope,
)
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.collect_statistics_queue_job_result import (
        CollectStatisticsQueueJobResult,
    )
    from ..models.physical_table_name import PhysicalTableName
    from ..models.statistics_collector_search_filters import (
        StatisticsCollectorSearchFilters,
    )


T = TypeVar("T", bound="CollectStatisticsOnTableQueueJobParameters")


@attr.s(auto_attribs=True)
class CollectStatisticsOnTableQueueJobParameters:
    """
    Attributes:
        connection (Union[Unset, str]): The name of the target connection.
        max_jobs_per_connection (Union[Unset, int]): The maximum number of concurrent 'run checks on table' jobs that
            could be run on this connection. Limits the number of concurrent jobs.
        table (Union[Unset, PhysicalTableName]):
        statistics_collector_search_filters (Union[Unset, StatisticsCollectorSearchFilters]):
        data_scope (Union[Unset, CollectStatisticsOnTableQueueJobParametersDataScope]): The target scope of collecting
            statistics. Statistics could be collected on a whole table or for each data grouping separately.
        dummy_sensor_execution (Union[Unset, bool]): Boolean flag that enables a dummy statistics collection (sensors
            are executed, but the statistics results are not written to the parquet files).
        collect_statistics_result (Union[Unset, CollectStatisticsQueueJobResult]): Returns the result with the summary
            of the statistics collected.
    """

    connection: Union[Unset, str] = UNSET
    max_jobs_per_connection: Union[Unset, int] = UNSET
    table: Union[Unset, "PhysicalTableName"] = UNSET
    statistics_collector_search_filters: Union[
        Unset, "StatisticsCollectorSearchFilters"
    ] = UNSET
    data_scope: Union[
        Unset, CollectStatisticsOnTableQueueJobParametersDataScope
    ] = UNSET
    dummy_sensor_execution: Union[Unset, bool] = UNSET
    collect_statistics_result: Union[Unset, "CollectStatisticsQueueJobResult"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        max_jobs_per_connection = self.max_jobs_per_connection
        table: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.table, Unset):
            table = self.table.to_dict()

        statistics_collector_search_filters: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.statistics_collector_search_filters, Unset):
            statistics_collector_search_filters = (
                self.statistics_collector_search_filters.to_dict()
            )

        data_scope: Union[Unset, str] = UNSET
        if not isinstance(self.data_scope, Unset):
            data_scope = self.data_scope.value

        dummy_sensor_execution = self.dummy_sensor_execution
        collect_statistics_result: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.collect_statistics_result, Unset):
            collect_statistics_result = self.collect_statistics_result.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if max_jobs_per_connection is not UNSET:
            field_dict["maxJobsPerConnection"] = max_jobs_per_connection
        if table is not UNSET:
            field_dict["table"] = table
        if statistics_collector_search_filters is not UNSET:
            field_dict[
                "statisticsCollectorSearchFilters"
            ] = statistics_collector_search_filters
        if data_scope is not UNSET:
            field_dict["dataScope"] = data_scope
        if dummy_sensor_execution is not UNSET:
            field_dict["dummySensorExecution"] = dummy_sensor_execution
        if collect_statistics_result is not UNSET:
            field_dict["collectStatisticsResult"] = collect_statistics_result

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.collect_statistics_queue_job_result import (
            CollectStatisticsQueueJobResult,
        )
        from ..models.physical_table_name import PhysicalTableName
        from ..models.statistics_collector_search_filters import (
            StatisticsCollectorSearchFilters,
        )

        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        max_jobs_per_connection = d.pop("maxJobsPerConnection", UNSET)

        _table = d.pop("table", UNSET)
        table: Union[Unset, PhysicalTableName]
        if isinstance(_table, Unset):
            table = UNSET
        else:
            table = PhysicalTableName.from_dict(_table)

        _statistics_collector_search_filters = d.pop(
            "statisticsCollectorSearchFilters", UNSET
        )
        statistics_collector_search_filters: Union[
            Unset, StatisticsCollectorSearchFilters
        ]
        if isinstance(_statistics_collector_search_filters, Unset):
            statistics_collector_search_filters = UNSET
        else:
            statistics_collector_search_filters = (
                StatisticsCollectorSearchFilters.from_dict(
                    _statistics_collector_search_filters
                )
            )

        _data_scope = d.pop("dataScope", UNSET)
        data_scope: Union[Unset, CollectStatisticsOnTableQueueJobParametersDataScope]
        if isinstance(_data_scope, Unset):
            data_scope = UNSET
        else:
            data_scope = CollectStatisticsOnTableQueueJobParametersDataScope(
                _data_scope
            )

        dummy_sensor_execution = d.pop("dummySensorExecution", UNSET)

        _collect_statistics_result = d.pop("collectStatisticsResult", UNSET)
        collect_statistics_result: Union[Unset, CollectStatisticsQueueJobResult]
        if isinstance(_collect_statistics_result, Unset):
            collect_statistics_result = UNSET
        else:
            collect_statistics_result = CollectStatisticsQueueJobResult.from_dict(
                _collect_statistics_result
            )

        collect_statistics_on_table_queue_job_parameters = cls(
            connection=connection,
            max_jobs_per_connection=max_jobs_per_connection,
            table=table,
            statistics_collector_search_filters=statistics_collector_search_filters,
            data_scope=data_scope,
            dummy_sensor_execution=dummy_sensor_execution,
            collect_statistics_result=collect_statistics_result,
        )

        collect_statistics_on_table_queue_job_parameters.additional_properties = d
        return collect_statistics_on_table_queue_job_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_datatype_date_match_format_percent_check_spec import (
        ColumnDatatypeDateMatchFormatPercentCheckSpec,
    )
    from ..models.column_datatype_string_datatype_changed_check_spec import (
        ColumnDatatypeStringDatatypeChangedCheckSpec,
    )


T = TypeVar("T", bound="ColumnDatatypeDailyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class ColumnDatatypeDailyPartitionedChecksSpec:
    """
    Attributes:
        daily_partition_date_match_format_percent (Union[Unset, ColumnDatatypeDateMatchFormatPercentCheckSpec]):
        daily_partition_string_datatype_changed (Union[Unset, ColumnDatatypeStringDatatypeChangedCheckSpec]):
    """

    daily_partition_date_match_format_percent: Union[
        Unset, "ColumnDatatypeDateMatchFormatPercentCheckSpec"
    ] = UNSET
    daily_partition_string_datatype_changed: Union[
        Unset, "ColumnDatatypeStringDatatypeChangedCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_partition_date_match_format_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_date_match_format_percent, Unset):
            daily_partition_date_match_format_percent = (
                self.daily_partition_date_match_format_percent.to_dict()
            )

        daily_partition_string_datatype_changed: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_string_datatype_changed, Unset):
            daily_partition_string_datatype_changed = (
                self.daily_partition_string_datatype_changed.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_partition_date_match_format_percent is not UNSET:
            field_dict[
                "daily_partition_date_match_format_percent"
            ] = daily_partition_date_match_format_percent
        if daily_partition_string_datatype_changed is not UNSET:
            field_dict[
                "daily_partition_string_datatype_changed"
            ] = daily_partition_string_datatype_changed

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_datatype_date_match_format_percent_check_spec import (
            ColumnDatatypeDateMatchFormatPercentCheckSpec,
        )
        from ..models.column_datatype_string_datatype_changed_check_spec import (
            ColumnDatatypeStringDatatypeChangedCheckSpec,
        )

        d = src_dict.copy()
        _daily_partition_date_match_format_percent = d.pop(
            "daily_partition_date_match_format_percent", UNSET
        )
        daily_partition_date_match_format_percent: Union[
            Unset, ColumnDatatypeDateMatchFormatPercentCheckSpec
        ]
        if isinstance(_daily_partition_date_match_format_percent, Unset):
            daily_partition_date_match_format_percent = UNSET
        else:
            daily_partition_date_match_format_percent = (
                ColumnDatatypeDateMatchFormatPercentCheckSpec.from_dict(
                    _daily_partition_date_match_format_percent
                )
            )

        _daily_partition_string_datatype_changed = d.pop(
            "daily_partition_string_datatype_changed", UNSET
        )
        daily_partition_string_datatype_changed: Union[
            Unset, ColumnDatatypeStringDatatypeChangedCheckSpec
        ]
        if isinstance(_daily_partition_string_datatype_changed, Unset):
            daily_partition_string_datatype_changed = UNSET
        else:
            daily_partition_string_datatype_changed = (
                ColumnDatatypeStringDatatypeChangedCheckSpec.from_dict(
                    _daily_partition_string_datatype_changed
                )
            )

        column_datatype_daily_partitioned_checks_spec = cls(
            daily_partition_date_match_format_percent=daily_partition_date_match_format_percent,
            daily_partition_string_datatype_changed=daily_partition_string_datatype_changed,
        )

        column_datatype_daily_partitioned_checks_spec.additional_properties = d
        return column_datatype_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_anomaly_stationary_null_percent_30_days_check_spec import (
        ColumnAnomalyStationaryNullPercent30DaysCheckSpec,
    )
    from ..models.column_anomaly_stationary_null_percent_check_spec import (
        ColumnAnomalyStationaryNullPercentCheckSpec,
    )
    from ..models.column_change_null_percent_check_spec import (
        ColumnChangeNullPercentCheckSpec,
    )
    from ..models.column_change_null_percent_since_7_days_check_spec import (
        ColumnChangeNullPercentSince7DaysCheckSpec,
    )
    from ..models.column_change_null_percent_since_30_days_check_spec import (
        ColumnChangeNullPercentSince30DaysCheckSpec,
    )
    from ..models.column_change_null_percent_since_yesterday_check_spec import (
        ColumnChangeNullPercentSinceYesterdayCheckSpec,
    )
    from ..models.column_not_nulls_count_check_spec import ColumnNotNullsCountCheckSpec
    from ..models.column_not_nulls_percent_check_spec import (
        ColumnNotNullsPercentCheckSpec,
    )
    from ..models.column_nulls_count_check_spec import ColumnNullsCountCheckSpec
    from ..models.column_nulls_percent_check_spec import ColumnNullsPercentCheckSpec


T = TypeVar("T", bound="ColumnNullsDailyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class ColumnNullsDailyPartitionedChecksSpec:
    """
    Attributes:
        daily_partition_nulls_count (Union[Unset, ColumnNullsCountCheckSpec]):
        daily_partition_nulls_percent (Union[Unset, ColumnNullsPercentCheckSpec]):
        daily_partition_nulls_percent_anomaly_stationary (Union[Unset, ColumnAnomalyStationaryNullPercentCheckSpec]):
        daily_partition_nulls_percent_change (Union[Unset, ColumnChangeNullPercentCheckSpec]):
        daily_partition_nulls_percent_change_yesterday (Union[Unset, ColumnChangeNullPercentSinceYesterdayCheckSpec]):
        daily_partition_not_nulls_count (Union[Unset, ColumnNotNullsCountCheckSpec]):
        daily_partition_not_nulls_percent (Union[Unset, ColumnNotNullsPercentCheckSpec]):
        daily_partition_nulls_percent_anomaly_stationary_30_days (Union[Unset,
            ColumnAnomalyStationaryNullPercent30DaysCheckSpec]):
        daily_partition_nulls_percent_change_7_days (Union[Unset, ColumnChangeNullPercentSince7DaysCheckSpec]):
        daily_partition_nulls_percent_change_30_days (Union[Unset, ColumnChangeNullPercentSince30DaysCheckSpec]):
    """

    daily_partition_nulls_count: Union[Unset, "ColumnNullsCountCheckSpec"] = UNSET
    daily_partition_nulls_percent: Union[Unset, "ColumnNullsPercentCheckSpec"] = UNSET
    daily_partition_nulls_percent_anomaly_stationary: Union[
        Unset, "ColumnAnomalyStationaryNullPercentCheckSpec"
    ] = UNSET
    daily_partition_nulls_percent_change: Union[
        Unset, "ColumnChangeNullPercentCheckSpec"
    ] = UNSET
    daily_partition_nulls_percent_change_yesterday: Union[
        Unset, "ColumnChangeNullPercentSinceYesterdayCheckSpec"
    ] = UNSET
    daily_partition_not_nulls_count: Union[
        Unset, "ColumnNotNullsCountCheckSpec"
    ] = UNSET
    daily_partition_not_nulls_percent: Union[
        Unset, "ColumnNotNullsPercentCheckSpec"
    ] = UNSET
    daily_partition_nulls_percent_anomaly_stationary_30_days: Union[
        Unset, "ColumnAnomalyStationaryNullPercent30DaysCheckSpec"
    ] = UNSET
    daily_partition_nulls_percent_change_7_days: Union[
        Unset, "ColumnChangeNullPercentSince7DaysCheckSpec"
    ] = UNSET
    daily_partition_nulls_percent_change_30_days: Union[
        Unset, "ColumnChangeNullPercentSince30DaysCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_partition_nulls_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_nulls_count, Unset):
            daily_partition_nulls_count = self.daily_partition_nulls_count.to_dict()

        daily_partition_nulls_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_nulls_percent, Unset):
            daily_partition_nulls_percent = self.daily_partition_nulls_percent.to_dict()

        daily_partition_nulls_percent_anomaly_stationary: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_nulls_percent_anomaly_stationary, Unset):
            daily_partition_nulls_percent_anomaly_stationary = (
                self.daily_partition_nulls_percent_anomaly_stationary.to_dict()
            )

        daily_partition_nulls_percent_change: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_nulls_percent_change, Unset):
            daily_partition_nulls_percent_change = (
                self.daily_partition_nulls_percent_change.to_dict()
            )

        daily_partition_nulls_percent_change_yesterday: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_nulls_percent_change_yesterday, Unset):
            daily_partition_nulls_percent_change_yesterday = (
                self.daily_partition_nulls_percent_change_yesterday.to_dict()
            )

        daily_partition_not_nulls_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_not_nulls_count, Unset):
            daily_partition_not_nulls_count = (
                self.daily_partition_not_nulls_count.to_dict()
            )

        daily_partition_not_nulls_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.daily_partition_not_nulls_percent, Unset):
            daily_partition_not_nulls_percent = (
                self.daily_partition_not_nulls_percent.to_dict()
            )

        daily_partition_nulls_percent_anomaly_stationary_30_days: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(
            self.daily_partition_nulls_percent_anomaly_stationary_30_days, Unset
        ):
            daily_partition_nulls_percent_anomaly_stationary_30_days = (
                self.daily_partition_nulls_percent_anomaly_stationary_30_days.to_dict()
            )

        daily_partition_nulls_percent_change_7_days: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_nulls_percent_change_7_days, Unset):
            daily_partition_nulls_percent_change_7_days = (
                self.daily_partition_nulls_percent_change_7_days.to_dict()
            )

        daily_partition_nulls_percent_change_30_days: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.daily_partition_nulls_percent_change_30_days, Unset):
            daily_partition_nulls_percent_change_30_days = (
                self.daily_partition_nulls_percent_change_30_days.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_partition_nulls_count is not UNSET:
            field_dict["daily_partition_nulls_count"] = daily_partition_nulls_count
        if daily_partition_nulls_percent is not UNSET:
            field_dict["daily_partition_nulls_percent"] = daily_partition_nulls_percent
        if daily_partition_nulls_percent_anomaly_stationary is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_anomaly_stationary"
            ] = daily_partition_nulls_percent_anomaly_stationary
        if daily_partition_nulls_percent_change is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_change"
            ] = daily_partition_nulls_percent_change
        if daily_partition_nulls_percent_change_yesterday is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_change_yesterday"
            ] = daily_partition_nulls_percent_change_yesterday
        if daily_partition_not_nulls_count is not UNSET:
            field_dict[
                "daily_partition_not_nulls_count"
            ] = daily_partition_not_nulls_count
        if daily_partition_not_nulls_percent is not UNSET:
            field_dict[
                "daily_partition_not_nulls_percent"
            ] = daily_partition_not_nulls_percent
        if daily_partition_nulls_percent_anomaly_stationary_30_days is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_anomaly_stationary_30_days"
            ] = daily_partition_nulls_percent_anomaly_stationary_30_days
        if daily_partition_nulls_percent_change_7_days is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_change_7_days"
            ] = daily_partition_nulls_percent_change_7_days
        if daily_partition_nulls_percent_change_30_days is not UNSET:
            field_dict[
                "daily_partition_nulls_percent_change_30_days"
            ] = daily_partition_nulls_percent_change_30_days

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_anomaly_stationary_null_percent_30_days_check_spec import (
            ColumnAnomalyStationaryNullPercent30DaysCheckSpec,
        )
        from ..models.column_anomaly_stationary_null_percent_check_spec import (
            ColumnAnomalyStationaryNullPercentCheckSpec,
        )
        from ..models.column_change_null_percent_check_spec import (
            ColumnChangeNullPercentCheckSpec,
        )
        from ..models.column_change_null_percent_since_7_days_check_spec import (
            ColumnChangeNullPercentSince7DaysCheckSpec,
        )
        from ..models.column_change_null_percent_since_30_days_check_spec import (
            ColumnChangeNullPercentSince30DaysCheckSpec,
        )
        from ..models.column_change_null_percent_since_yesterday_check_spec import (
            ColumnChangeNullPercentSinceYesterdayCheckSpec,
        )
        from ..models.column_not_nulls_count_check_spec import (
            ColumnNotNullsCountCheckSpec,
        )
        from ..models.column_not_nulls_percent_check_spec import (
            ColumnNotNullsPercentCheckSpec,
        )
        from ..models.column_nulls_count_check_spec import ColumnNullsCountCheckSpec
        from ..models.column_nulls_percent_check_spec import ColumnNullsPercentCheckSpec

        d = src_dict.copy()
        _daily_partition_nulls_count = d.pop("daily_partition_nulls_count", UNSET)
        daily_partition_nulls_count: Union[Unset, ColumnNullsCountCheckSpec]
        if isinstance(_daily_partition_nulls_count, Unset):
            daily_partition_nulls_count = UNSET
        else:
            daily_partition_nulls_count = ColumnNullsCountCheckSpec.from_dict(
                _daily_partition_nulls_count
            )

        _daily_partition_nulls_percent = d.pop("daily_partition_nulls_percent", UNSET)
        daily_partition_nulls_percent: Union[Unset, ColumnNullsPercentCheckSpec]
        if isinstance(_daily_partition_nulls_percent, Unset):
            daily_partition_nulls_percent = UNSET
        else:
            daily_partition_nulls_percent = ColumnNullsPercentCheckSpec.from_dict(
                _daily_partition_nulls_percent
            )

        _daily_partition_nulls_percent_anomaly_stationary = d.pop(
            "daily_partition_nulls_percent_anomaly_stationary", UNSET
        )
        daily_partition_nulls_percent_anomaly_stationary: Union[
            Unset, ColumnAnomalyStationaryNullPercentCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_anomaly_stationary, Unset):
            daily_partition_nulls_percent_anomaly_stationary = UNSET
        else:
            daily_partition_nulls_percent_anomaly_stationary = (
                ColumnAnomalyStationaryNullPercentCheckSpec.from_dict(
                    _daily_partition_nulls_percent_anomaly_stationary
                )
            )

        _daily_partition_nulls_percent_change = d.pop(
            "daily_partition_nulls_percent_change", UNSET
        )
        daily_partition_nulls_percent_change: Union[
            Unset, ColumnChangeNullPercentCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_change, Unset):
            daily_partition_nulls_percent_change = UNSET
        else:
            daily_partition_nulls_percent_change = (
                ColumnChangeNullPercentCheckSpec.from_dict(
                    _daily_partition_nulls_percent_change
                )
            )

        _daily_partition_nulls_percent_change_yesterday = d.pop(
            "daily_partition_nulls_percent_change_yesterday", UNSET
        )
        daily_partition_nulls_percent_change_yesterday: Union[
            Unset, ColumnChangeNullPercentSinceYesterdayCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_change_yesterday, Unset):
            daily_partition_nulls_percent_change_yesterday = UNSET
        else:
            daily_partition_nulls_percent_change_yesterday = (
                ColumnChangeNullPercentSinceYesterdayCheckSpec.from_dict(
                    _daily_partition_nulls_percent_change_yesterday
                )
            )

        _daily_partition_not_nulls_count = d.pop(
            "daily_partition_not_nulls_count", UNSET
        )
        daily_partition_not_nulls_count: Union[Unset, ColumnNotNullsCountCheckSpec]
        if isinstance(_daily_partition_not_nulls_count, Unset):
            daily_partition_not_nulls_count = UNSET
        else:
            daily_partition_not_nulls_count = ColumnNotNullsCountCheckSpec.from_dict(
                _daily_partition_not_nulls_count
            )

        _daily_partition_not_nulls_percent = d.pop(
            "daily_partition_not_nulls_percent", UNSET
        )
        daily_partition_not_nulls_percent: Union[Unset, ColumnNotNullsPercentCheckSpec]
        if isinstance(_daily_partition_not_nulls_percent, Unset):
            daily_partition_not_nulls_percent = UNSET
        else:
            daily_partition_not_nulls_percent = (
                ColumnNotNullsPercentCheckSpec.from_dict(
                    _daily_partition_not_nulls_percent
                )
            )

        _daily_partition_nulls_percent_anomaly_stationary_30_days = d.pop(
            "daily_partition_nulls_percent_anomaly_stationary_30_days", UNSET
        )
        daily_partition_nulls_percent_anomaly_stationary_30_days: Union[
            Unset, ColumnAnomalyStationaryNullPercent30DaysCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_anomaly_stationary_30_days, Unset):
            daily_partition_nulls_percent_anomaly_stationary_30_days = UNSET
        else:
            daily_partition_nulls_percent_anomaly_stationary_30_days = (
                ColumnAnomalyStationaryNullPercent30DaysCheckSpec.from_dict(
                    _daily_partition_nulls_percent_anomaly_stationary_30_days
                )
            )

        _daily_partition_nulls_percent_change_7_days = d.pop(
            "daily_partition_nulls_percent_change_7_days", UNSET
        )
        daily_partition_nulls_percent_change_7_days: Union[
            Unset, ColumnChangeNullPercentSince7DaysCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_change_7_days, Unset):
            daily_partition_nulls_percent_change_7_days = UNSET
        else:
            daily_partition_nulls_percent_change_7_days = (
                ColumnChangeNullPercentSince7DaysCheckSpec.from_dict(
                    _daily_partition_nulls_percent_change_7_days
                )
            )

        _daily_partition_nulls_percent_change_30_days = d.pop(
            "daily_partition_nulls_percent_change_30_days", UNSET
        )
        daily_partition_nulls_percent_change_30_days: Union[
            Unset, ColumnChangeNullPercentSince30DaysCheckSpec
        ]
        if isinstance(_daily_partition_nulls_percent_change_30_days, Unset):
            daily_partition_nulls_percent_change_30_days = UNSET
        else:
            daily_partition_nulls_percent_change_30_days = (
                ColumnChangeNullPercentSince30DaysCheckSpec.from_dict(
                    _daily_partition_nulls_percent_change_30_days
                )
            )

        column_nulls_daily_partitioned_checks_spec = cls(
            daily_partition_nulls_count=daily_partition_nulls_count,
            daily_partition_nulls_percent=daily_partition_nulls_percent,
            daily_partition_nulls_percent_anomaly_stationary=daily_partition_nulls_percent_anomaly_stationary,
            daily_partition_nulls_percent_change=daily_partition_nulls_percent_change,
            daily_partition_nulls_percent_change_yesterday=daily_partition_nulls_percent_change_yesterday,
            daily_partition_not_nulls_count=daily_partition_not_nulls_count,
            daily_partition_not_nulls_percent=daily_partition_not_nulls_percent,
            daily_partition_nulls_percent_anomaly_stationary_30_days=daily_partition_nulls_percent_anomaly_stationary_30_days,
            daily_partition_nulls_percent_change_7_days=daily_partition_nulls_percent_change_7_days,
            daily_partition_nulls_percent_change_30_days=daily_partition_nulls_percent_change_30_days,
        )

        column_nulls_daily_partitioned_checks_spec.additional_properties = d
        return column_nulls_daily_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ProviderSensorDefinitionSpecType(str, Enum):
    JAVA_CLASS = "java_class"
    SQL_TEMPLATE = "sql_template"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_expected_strings_in_top_values_count_check_spec import (
        ColumnExpectedStringsInTopValuesCountCheckSpec,
    )
    from ..models.column_expected_strings_in_use_count_check_spec import (
        ColumnExpectedStringsInUseCountCheckSpec,
    )
    from ..models.column_string_boolean_placeholder_percent_check_spec import (
        ColumnStringBooleanPlaceholderPercentCheckSpec,
    )
    from ..models.column_string_datatype_detected_check_spec import (
        ColumnStringDatatypeDetectedCheckSpec,
    )
    from ..models.column_string_empty_count_check_spec import (
        ColumnStringEmptyCountCheckSpec,
    )
    from ..models.column_string_empty_percent_check_spec import (
        ColumnStringEmptyPercentCheckSpec,
    )
    from ..models.column_string_invalid_email_count_check_spec import (
        ColumnStringInvalidEmailCountCheckSpec,
    )
    from ..models.column_string_invalid_ip_4_address_count_check_spec import (
        ColumnStringInvalidIp4AddressCountCheckSpec,
    )
    from ..models.column_string_invalid_ip_6_address_count_check_spec import (
        ColumnStringInvalidIp6AddressCountCheckSpec,
    )
    from ..models.column_string_invalid_uuid_count_check_spec import (
        ColumnStringInvalidUuidCountCheckSpec,
    )
    from ..models.column_string_length_above_max_length_count_check_spec import (
        ColumnStringLengthAboveMaxLengthCountCheckSpec,
    )
    from ..models.column_string_length_above_max_length_percent_check_spec import (
        ColumnStringLengthAboveMaxLengthPercentCheckSpec,
    )
    from ..models.column_string_length_below_min_length_count_check_spec import (
        ColumnStringLengthBelowMinLengthCountCheckSpec,
    )
    from ..models.column_string_length_below_min_length_percent_check_spec import (
        ColumnStringLengthBelowMinLengthPercentCheckSpec,
    )
    from ..models.column_string_length_in_range_percent_check_spec import (
        ColumnStringLengthInRangePercentCheckSpec,
    )
    from ..models.column_string_match_date_regex_percent_check_spec import (
        ColumnStringMatchDateRegexPercentCheckSpec,
    )
    from ..models.column_string_match_name_regex_percent_check_spec import (
        ColumnStringMatchNameRegexPercentCheckSpec,
    )
    from ..models.column_string_match_regex_percent_check_spec import (
        ColumnStringMatchRegexPercentCheckSpec,
    )
    from ..models.column_string_max_length_check_spec import (
        ColumnStringMaxLengthCheckSpec,
    )
    from ..models.column_string_mean_length_check_spec import (
        ColumnStringMeanLengthCheckSpec,
    )
    from ..models.column_string_min_length_check_spec import (
        ColumnStringMinLengthCheckSpec,
    )
    from ..models.column_string_not_match_date_regex_count_check_spec import (
        ColumnStringNotMatchDateRegexCountCheckSpec,
    )
    from ..models.column_string_not_match_regex_count_check_spec import (
        ColumnStringNotMatchRegexCountCheckSpec,
    )
    from ..models.column_string_null_placeholder_count_check_spec import (
        ColumnStringNullPlaceholderCountCheckSpec,
    )
    from ..models.column_string_null_placeholder_percent_check_spec import (
        ColumnStringNullPlaceholderPercentCheckSpec,
    )
    from ..models.column_string_parsable_to_float_percent_check_spec import (
        ColumnStringParsableToFloatPercentCheckSpec,
    )
    from ..models.column_string_parsable_to_integer_percent_check_spec import (
        ColumnStringParsableToIntegerPercentCheckSpec,
    )
    from ..models.column_string_surrounded_by_whitespace_count_check_spec import (
        ColumnStringSurroundedByWhitespaceCountCheckSpec,
    )
    from ..models.column_string_surrounded_by_whitespace_percent_check_spec import (
        ColumnStringSurroundedByWhitespacePercentCheckSpec,
    )
    from ..models.column_string_valid_country_code_percent_check_spec import (
        ColumnStringValidCountryCodePercentCheckSpec,
    )
    from ..models.column_string_valid_currency_code_percent_check_spec import (
        ColumnStringValidCurrencyCodePercentCheckSpec,
    )
    from ..models.column_string_valid_dates_percent_check_spec import (
        ColumnStringValidDatesPercentCheckSpec,
    )
    from ..models.column_string_valid_uuid_percent_check_spec import (
        ColumnStringValidUuidPercentCheckSpec,
    )
    from ..models.column_string_value_in_set_percent_check_spec import (
        ColumnStringValueInSetPercentCheckSpec,
    )
    from ..models.column_string_whitespace_count_check_spec import (
        ColumnStringWhitespaceCountCheckSpec,
    )
    from ..models.column_string_whitespace_percent_check_spec import (
        ColumnStringWhitespacePercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnStringsMonthlyRecurringChecksSpec")


@attr.s(auto_attribs=True)
class ColumnStringsMonthlyRecurringChecksSpec:
    """
    Attributes:
        monthly_string_max_length (Union[Unset, ColumnStringMaxLengthCheckSpec]):
        monthly_string_min_length (Union[Unset, ColumnStringMinLengthCheckSpec]):
        monthly_string_mean_length (Union[Unset, ColumnStringMeanLengthCheckSpec]):
        monthly_string_length_below_min_length_count (Union[Unset, ColumnStringLengthBelowMinLengthCountCheckSpec]):
        monthly_string_length_below_min_length_percent (Union[Unset, ColumnStringLengthBelowMinLengthPercentCheckSpec]):
        monthly_string_length_above_max_length_count (Union[Unset, ColumnStringLengthAboveMaxLengthCountCheckSpec]):
        monthly_string_length_above_max_length_percent (Union[Unset, ColumnStringLengthAboveMaxLengthPercentCheckSpec]):
        monthly_string_length_in_range_percent (Union[Unset, ColumnStringLengthInRangePercentCheckSpec]):
        monthly_string_empty_count (Union[Unset, ColumnStringEmptyCountCheckSpec]):
        monthly_string_empty_percent (Union[Unset, ColumnStringEmptyPercentCheckSpec]):
        monthly_string_valid_dates_percent (Union[Unset, ColumnStringValidDatesPercentCheckSpec]):
        monthly_string_whitespace_count (Union[Unset, ColumnStringWhitespaceCountCheckSpec]):
        monthly_string_whitespace_percent (Union[Unset, ColumnStringWhitespacePercentCheckSpec]):
        monthly_string_surrounded_by_whitespace_count (Union[Unset, ColumnStringSurroundedByWhitespaceCountCheckSpec]):
        monthly_string_surrounded_by_whitespace_percent (Union[Unset,
            ColumnStringSurroundedByWhitespacePercentCheckSpec]):
        monthly_string_null_placeholder_count (Union[Unset, ColumnStringNullPlaceholderCountCheckSpec]):
        monthly_string_null_placeholder_percent (Union[Unset, ColumnStringNullPlaceholderPercentCheckSpec]):
        monthly_string_boolean_placeholder_percent (Union[Unset, ColumnStringBooleanPlaceholderPercentCheckSpec]):
        monthly_string_parsable_to_integer_percent (Union[Unset, ColumnStringParsableToIntegerPercentCheckSpec]):
        monthly_string_parsable_to_float_percent (Union[Unset, ColumnStringParsableToFloatPercentCheckSpec]):
        monthly_expected_strings_in_use_count (Union[Unset, ColumnExpectedStringsInUseCountCheckSpec]):
        monthly_string_value_in_set_percent (Union[Unset, ColumnStringValueInSetPercentCheckSpec]):
        monthly_string_valid_country_code_percent (Union[Unset, ColumnStringValidCountryCodePercentCheckSpec]):
        monthly_string_valid_currency_code_percent (Union[Unset, ColumnStringValidCurrencyCodePercentCheckSpec]):
        monthly_string_invalid_email_count (Union[Unset, ColumnStringInvalidEmailCountCheckSpec]):
        monthly_string_invalid_uuid_count (Union[Unset, ColumnStringInvalidUuidCountCheckSpec]):
        monthly_string_valid_uuid_percent (Union[Unset, ColumnStringValidUuidPercentCheckSpec]):
        monthly_string_invalid_ip4_address_count (Union[Unset, ColumnStringInvalidIp4AddressCountCheckSpec]):
        monthly_string_invalid_ip6_address_count (Union[Unset, ColumnStringInvalidIp6AddressCountCheckSpec]):
        monthly_string_not_match_regex_count (Union[Unset, ColumnStringNotMatchRegexCountCheckSpec]):
        monthly_string_match_regex_percent (Union[Unset, ColumnStringMatchRegexPercentCheckSpec]):
        monthly_string_not_match_date_regex_count (Union[Unset, ColumnStringNotMatchDateRegexCountCheckSpec]):
        monthly_string_match_date_regex_percent (Union[Unset, ColumnStringMatchDateRegexPercentCheckSpec]):
        monthly_string_match_name_regex_percent (Union[Unset, ColumnStringMatchNameRegexPercentCheckSpec]):
        monthly_expected_strings_in_top_values_count (Union[Unset, ColumnExpectedStringsInTopValuesCountCheckSpec]):
        monthly_string_datatype_detected (Union[Unset, ColumnStringDatatypeDetectedCheckSpec]):
    """

    monthly_string_max_length: Union[Unset, "ColumnStringMaxLengthCheckSpec"] = UNSET
    monthly_string_min_length: Union[Unset, "ColumnStringMinLengthCheckSpec"] = UNSET
    monthly_string_mean_length: Union[Unset, "ColumnStringMeanLengthCheckSpec"] = UNSET
    monthly_string_length_below_min_length_count: Union[
        Unset, "ColumnStringLengthBelowMinLengthCountCheckSpec"
    ] = UNSET
    monthly_string_length_below_min_length_percent: Union[
        Unset, "ColumnStringLengthBelowMinLengthPercentCheckSpec"
    ] = UNSET
    monthly_string_length_above_max_length_count: Union[
        Unset, "ColumnStringLengthAboveMaxLengthCountCheckSpec"
    ] = UNSET
    monthly_string_length_above_max_length_percent: Union[
        Unset, "ColumnStringLengthAboveMaxLengthPercentCheckSpec"
    ] = UNSET
    monthly_string_length_in_range_percent: Union[
        Unset, "ColumnStringLengthInRangePercentCheckSpec"
    ] = UNSET
    monthly_string_empty_count: Union[Unset, "ColumnStringEmptyCountCheckSpec"] = UNSET
    monthly_string_empty_percent: Union[
        Unset, "ColumnStringEmptyPercentCheckSpec"
    ] = UNSET
    monthly_string_valid_dates_percent: Union[
        Unset, "ColumnStringValidDatesPercentCheckSpec"
    ] = UNSET
    monthly_string_whitespace_count: Union[
        Unset, "ColumnStringWhitespaceCountCheckSpec"
    ] = UNSET
    monthly_string_whitespace_percent: Union[
        Unset, "ColumnStringWhitespacePercentCheckSpec"
    ] = UNSET
    monthly_string_surrounded_by_whitespace_count: Union[
        Unset, "ColumnStringSurroundedByWhitespaceCountCheckSpec"
    ] = UNSET
    monthly_string_surrounded_by_whitespace_percent: Union[
        Unset, "ColumnStringSurroundedByWhitespacePercentCheckSpec"
    ] = UNSET
    monthly_string_null_placeholder_count: Union[
        Unset, "ColumnStringNullPlaceholderCountCheckSpec"
    ] = UNSET
    monthly_string_null_placeholder_percent: Union[
        Unset, "ColumnStringNullPlaceholderPercentCheckSpec"
    ] = UNSET
    monthly_string_boolean_placeholder_percent: Union[
        Unset, "ColumnStringBooleanPlaceholderPercentCheckSpec"
    ] = UNSET
    monthly_string_parsable_to_integer_percent: Union[
        Unset, "ColumnStringParsableToIntegerPercentCheckSpec"
    ] = UNSET
    monthly_string_parsable_to_float_percent: Union[
        Unset, "ColumnStringParsableToFloatPercentCheckSpec"
    ] = UNSET
    monthly_expected_strings_in_use_count: Union[
        Unset, "ColumnExpectedStringsInUseCountCheckSpec"
    ] = UNSET
    monthly_string_value_in_set_percent: Union[
        Unset, "ColumnStringValueInSetPercentCheckSpec"
    ] = UNSET
    monthly_string_valid_country_code_percent: Union[
        Unset, "ColumnStringValidCountryCodePercentCheckSpec"
    ] = UNSET
    monthly_string_valid_currency_code_percent: Union[
        Unset, "ColumnStringValidCurrencyCodePercentCheckSpec"
    ] = UNSET
    monthly_string_invalid_email_count: Union[
        Unset, "ColumnStringInvalidEmailCountCheckSpec"
    ] = UNSET
    monthly_string_invalid_uuid_count: Union[
        Unset, "ColumnStringInvalidUuidCountCheckSpec"
    ] = UNSET
    monthly_string_valid_uuid_percent: Union[
        Unset, "ColumnStringValidUuidPercentCheckSpec"
    ] = UNSET
    monthly_string_invalid_ip4_address_count: Union[
        Unset, "ColumnStringInvalidIp4AddressCountCheckSpec"
    ] = UNSET
    monthly_string_invalid_ip6_address_count: Union[
        Unset, "ColumnStringInvalidIp6AddressCountCheckSpec"
    ] = UNSET
    monthly_string_not_match_regex_count: Union[
        Unset, "ColumnStringNotMatchRegexCountCheckSpec"
    ] = UNSET
    monthly_string_match_regex_percent: Union[
        Unset, "ColumnStringMatchRegexPercentCheckSpec"
    ] = UNSET
    monthly_string_not_match_date_regex_count: Union[
        Unset, "ColumnStringNotMatchDateRegexCountCheckSpec"
    ] = UNSET
    monthly_string_match_date_regex_percent: Union[
        Unset, "ColumnStringMatchDateRegexPercentCheckSpec"
    ] = UNSET
    monthly_string_match_name_regex_percent: Union[
        Unset, "ColumnStringMatchNameRegexPercentCheckSpec"
    ] = UNSET
    monthly_expected_strings_in_top_values_count: Union[
        Unset, "ColumnExpectedStringsInTopValuesCountCheckSpec"
    ] = UNSET
    monthly_string_datatype_detected: Union[
        Unset, "ColumnStringDatatypeDetectedCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_string_max_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_max_length, Unset):
            monthly_string_max_length = self.monthly_string_max_length.to_dict()

        monthly_string_min_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_min_length, Unset):
            monthly_string_min_length = self.monthly_string_min_length.to_dict()

        monthly_string_mean_length: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_mean_length, Unset):
            monthly_string_mean_length = self.monthly_string_mean_length.to_dict()

        monthly_string_length_below_min_length_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_length_below_min_length_count, Unset):
            monthly_string_length_below_min_length_count = (
                self.monthly_string_length_below_min_length_count.to_dict()
            )

        monthly_string_length_below_min_length_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_length_below_min_length_percent, Unset):
            monthly_string_length_below_min_length_percent = (
                self.monthly_string_length_below_min_length_percent.to_dict()
            )

        monthly_string_length_above_max_length_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_length_above_max_length_count, Unset):
            monthly_string_length_above_max_length_count = (
                self.monthly_string_length_above_max_length_count.to_dict()
            )

        monthly_string_length_above_max_length_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_length_above_max_length_percent, Unset):
            monthly_string_length_above_max_length_percent = (
                self.monthly_string_length_above_max_length_percent.to_dict()
            )

        monthly_string_length_in_range_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_length_in_range_percent, Unset):
            monthly_string_length_in_range_percent = (
                self.monthly_string_length_in_range_percent.to_dict()
            )

        monthly_string_empty_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_empty_count, Unset):
            monthly_string_empty_count = self.monthly_string_empty_count.to_dict()

        monthly_string_empty_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_empty_percent, Unset):
            monthly_string_empty_percent = self.monthly_string_empty_percent.to_dict()

        monthly_string_valid_dates_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_valid_dates_percent, Unset):
            monthly_string_valid_dates_percent = (
                self.monthly_string_valid_dates_percent.to_dict()
            )

        monthly_string_whitespace_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_whitespace_count, Unset):
            monthly_string_whitespace_count = (
                self.monthly_string_whitespace_count.to_dict()
            )

        monthly_string_whitespace_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_whitespace_percent, Unset):
            monthly_string_whitespace_percent = (
                self.monthly_string_whitespace_percent.to_dict()
            )

        monthly_string_surrounded_by_whitespace_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_surrounded_by_whitespace_count, Unset):
            monthly_string_surrounded_by_whitespace_count = (
                self.monthly_string_surrounded_by_whitespace_count.to_dict()
            )

        monthly_string_surrounded_by_whitespace_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_string_surrounded_by_whitespace_percent, Unset):
            monthly_string_surrounded_by_whitespace_percent = (
                self.monthly_string_surrounded_by_whitespace_percent.to_dict()
            )

        monthly_string_null_placeholder_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_null_placeholder_count, Unset):
            monthly_string_null_placeholder_count = (
                self.monthly_string_null_placeholder_count.to_dict()
            )

        monthly_string_null_placeholder_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_null_placeholder_percent, Unset):
            monthly_string_null_placeholder_percent = (
                self.monthly_string_null_placeholder_percent.to_dict()
            )

        monthly_string_boolean_placeholder_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_boolean_placeholder_percent, Unset):
            monthly_string_boolean_placeholder_percent = (
                self.monthly_string_boolean_placeholder_percent.to_dict()
            )

        monthly_string_parsable_to_integer_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_parsable_to_integer_percent, Unset):
            monthly_string_parsable_to_integer_percent = (
                self.monthly_string_parsable_to_integer_percent.to_dict()
            )

        monthly_string_parsable_to_float_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_parsable_to_float_percent, Unset):
            monthly_string_parsable_to_float_percent = (
                self.monthly_string_parsable_to_float_percent.to_dict()
            )

        monthly_expected_strings_in_use_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_expected_strings_in_use_count, Unset):
            monthly_expected_strings_in_use_count = (
                self.monthly_expected_strings_in_use_count.to_dict()
            )

        monthly_string_value_in_set_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_value_in_set_percent, Unset):
            monthly_string_value_in_set_percent = (
                self.monthly_string_value_in_set_percent.to_dict()
            )

        monthly_string_valid_country_code_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_valid_country_code_percent, Unset):
            monthly_string_valid_country_code_percent = (
                self.monthly_string_valid_country_code_percent.to_dict()
            )

        monthly_string_valid_currency_code_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_valid_currency_code_percent, Unset):
            monthly_string_valid_currency_code_percent = (
                self.monthly_string_valid_currency_code_percent.to_dict()
            )

        monthly_string_invalid_email_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_invalid_email_count, Unset):
            monthly_string_invalid_email_count = (
                self.monthly_string_invalid_email_count.to_dict()
            )

        monthly_string_invalid_uuid_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_invalid_uuid_count, Unset):
            monthly_string_invalid_uuid_count = (
                self.monthly_string_invalid_uuid_count.to_dict()
            )

        monthly_string_valid_uuid_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_valid_uuid_percent, Unset):
            monthly_string_valid_uuid_percent = (
                self.monthly_string_valid_uuid_percent.to_dict()
            )

        monthly_string_invalid_ip4_address_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_invalid_ip4_address_count, Unset):
            monthly_string_invalid_ip4_address_count = (
                self.monthly_string_invalid_ip4_address_count.to_dict()
            )

        monthly_string_invalid_ip6_address_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_invalid_ip6_address_count, Unset):
            monthly_string_invalid_ip6_address_count = (
                self.monthly_string_invalid_ip6_address_count.to_dict()
            )

        monthly_string_not_match_regex_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_not_match_regex_count, Unset):
            monthly_string_not_match_regex_count = (
                self.monthly_string_not_match_regex_count.to_dict()
            )

        monthly_string_match_regex_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_match_regex_percent, Unset):
            monthly_string_match_regex_percent = (
                self.monthly_string_match_regex_percent.to_dict()
            )

        monthly_string_not_match_date_regex_count: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_not_match_date_regex_count, Unset):
            monthly_string_not_match_date_regex_count = (
                self.monthly_string_not_match_date_regex_count.to_dict()
            )

        monthly_string_match_date_regex_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_match_date_regex_percent, Unset):
            monthly_string_match_date_regex_percent = (
                self.monthly_string_match_date_regex_percent.to_dict()
            )

        monthly_string_match_name_regex_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_match_name_regex_percent, Unset):
            monthly_string_match_name_regex_percent = (
                self.monthly_string_match_name_regex_percent.to_dict()
            )

        monthly_expected_strings_in_top_values_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_expected_strings_in_top_values_count, Unset):
            monthly_expected_strings_in_top_values_count = (
                self.monthly_expected_strings_in_top_values_count.to_dict()
            )

        monthly_string_datatype_detected: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_string_datatype_detected, Unset):
            monthly_string_datatype_detected = (
                self.monthly_string_datatype_detected.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_string_max_length is not UNSET:
            field_dict["monthly_string_max_length"] = monthly_string_max_length
        if monthly_string_min_length is not UNSET:
            field_dict["monthly_string_min_length"] = monthly_string_min_length
        if monthly_string_mean_length is not UNSET:
            field_dict["monthly_string_mean_length"] = monthly_string_mean_length
        if monthly_string_length_below_min_length_count is not UNSET:
            field_dict[
                "monthly_string_length_below_min_length_count"
            ] = monthly_string_length_below_min_length_count
        if monthly_string_length_below_min_length_percent is not UNSET:
            field_dict[
                "monthly_string_length_below_min_length_percent"
            ] = monthly_string_length_below_min_length_percent
        if monthly_string_length_above_max_length_count is not UNSET:
            field_dict[
                "monthly_string_length_above_max_length_count"
            ] = monthly_string_length_above_max_length_count
        if monthly_string_length_above_max_length_percent is not UNSET:
            field_dict[
                "monthly_string_length_above_max_length_percent"
            ] = monthly_string_length_above_max_length_percent
        if monthly_string_length_in_range_percent is not UNSET:
            field_dict[
                "monthly_string_length_in_range_percent"
            ] = monthly_string_length_in_range_percent
        if monthly_string_empty_count is not UNSET:
            field_dict["monthly_string_empty_count"] = monthly_string_empty_count
        if monthly_string_empty_percent is not UNSET:
            field_dict["monthly_string_empty_percent"] = monthly_string_empty_percent
        if monthly_string_valid_dates_percent is not UNSET:
            field_dict[
                "monthly_string_valid_dates_percent"
            ] = monthly_string_valid_dates_percent
        if monthly_string_whitespace_count is not UNSET:
            field_dict[
                "monthly_string_whitespace_count"
            ] = monthly_string_whitespace_count
        if monthly_string_whitespace_percent is not UNSET:
            field_dict[
                "monthly_string_whitespace_percent"
            ] = monthly_string_whitespace_percent
        if monthly_string_surrounded_by_whitespace_count is not UNSET:
            field_dict[
                "monthly_string_surrounded_by_whitespace_count"
            ] = monthly_string_surrounded_by_whitespace_count
        if monthly_string_surrounded_by_whitespace_percent is not UNSET:
            field_dict[
                "monthly_string_surrounded_by_whitespace_percent"
            ] = monthly_string_surrounded_by_whitespace_percent
        if monthly_string_null_placeholder_count is not UNSET:
            field_dict[
                "monthly_string_null_placeholder_count"
            ] = monthly_string_null_placeholder_count
        if monthly_string_null_placeholder_percent is not UNSET:
            field_dict[
                "monthly_string_null_placeholder_percent"
            ] = monthly_string_null_placeholder_percent
        if monthly_string_boolean_placeholder_percent is not UNSET:
            field_dict[
                "monthly_string_boolean_placeholder_percent"
            ] = monthly_string_boolean_placeholder_percent
        if monthly_string_parsable_to_integer_percent is not UNSET:
            field_dict[
                "monthly_string_parsable_to_integer_percent"
            ] = monthly_string_parsable_to_integer_percent
        if monthly_string_parsable_to_float_percent is not UNSET:
            field_dict[
                "monthly_string_parsable_to_float_percent"
            ] = monthly_string_parsable_to_float_percent
        if monthly_expected_strings_in_use_count is not UNSET:
            field_dict[
                "monthly_expected_strings_in_use_count"
            ] = monthly_expected_strings_in_use_count
        if monthly_string_value_in_set_percent is not UNSET:
            field_dict[
                "monthly_string_value_in_set_percent"
            ] = monthly_string_value_in_set_percent
        if monthly_string_valid_country_code_percent is not UNSET:
            field_dict[
                "monthly_string_valid_country_code_percent"
            ] = monthly_string_valid_country_code_percent
        if monthly_string_valid_currency_code_percent is not UNSET:
            field_dict[
                "monthly_string_valid_currency_code_percent"
            ] = monthly_string_valid_currency_code_percent
        if monthly_string_invalid_email_count is not UNSET:
            field_dict[
                "monthly_string_invalid_email_count"
            ] = monthly_string_invalid_email_count
        if monthly_string_invalid_uuid_count is not UNSET:
            field_dict[
                "monthly_string_invalid_uuid_count"
            ] = monthly_string_invalid_uuid_count
        if monthly_string_valid_uuid_percent is not UNSET:
            field_dict[
                "monthly_string_valid_uuid_percent"
            ] = monthly_string_valid_uuid_percent
        if monthly_string_invalid_ip4_address_count is not UNSET:
            field_dict[
                "monthly_string_invalid_ip4_address_count"
            ] = monthly_string_invalid_ip4_address_count
        if monthly_string_invalid_ip6_address_count is not UNSET:
            field_dict[
                "monthly_string_invalid_ip6_address_count"
            ] = monthly_string_invalid_ip6_address_count
        if monthly_string_not_match_regex_count is not UNSET:
            field_dict[
                "monthly_string_not_match_regex_count"
            ] = monthly_string_not_match_regex_count
        if monthly_string_match_regex_percent is not UNSET:
            field_dict[
                "monthly_string_match_regex_percent"
            ] = monthly_string_match_regex_percent
        if monthly_string_not_match_date_regex_count is not UNSET:
            field_dict[
                "monthly_string_not_match_date_regex_count"
            ] = monthly_string_not_match_date_regex_count
        if monthly_string_match_date_regex_percent is not UNSET:
            field_dict[
                "monthly_string_match_date_regex_percent"
            ] = monthly_string_match_date_regex_percent
        if monthly_string_match_name_regex_percent is not UNSET:
            field_dict[
                "monthly_string_match_name_regex_percent"
            ] = monthly_string_match_name_regex_percent
        if monthly_expected_strings_in_top_values_count is not UNSET:
            field_dict[
                "monthly_expected_strings_in_top_values_count"
            ] = monthly_expected_strings_in_top_values_count
        if monthly_string_datatype_detected is not UNSET:
            field_dict[
                "monthly_string_datatype_detected"
            ] = monthly_string_datatype_detected

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_expected_strings_in_top_values_count_check_spec import (
            ColumnExpectedStringsInTopValuesCountCheckSpec,
        )
        from ..models.column_expected_strings_in_use_count_check_spec import (
            ColumnExpectedStringsInUseCountCheckSpec,
        )
        from ..models.column_string_boolean_placeholder_percent_check_spec import (
            ColumnStringBooleanPlaceholderPercentCheckSpec,
        )
        from ..models.column_string_datatype_detected_check_spec import (
            ColumnStringDatatypeDetectedCheckSpec,
        )
        from ..models.column_string_empty_count_check_spec import (
            ColumnStringEmptyCountCheckSpec,
        )
        from ..models.column_string_empty_percent_check_spec import (
            ColumnStringEmptyPercentCheckSpec,
        )
        from ..models.column_string_invalid_email_count_check_spec import (
            ColumnStringInvalidEmailCountCheckSpec,
        )
        from ..models.column_string_invalid_ip_4_address_count_check_spec import (
            ColumnStringInvalidIp4AddressCountCheckSpec,
        )
        from ..models.column_string_invalid_ip_6_address_count_check_spec import (
            ColumnStringInvalidIp6AddressCountCheckSpec,
        )
        from ..models.column_string_invalid_uuid_count_check_spec import (
            ColumnStringInvalidUuidCountCheckSpec,
        )
        from ..models.column_string_length_above_max_length_count_check_spec import (
            ColumnStringLengthAboveMaxLengthCountCheckSpec,
        )
        from ..models.column_string_length_above_max_length_percent_check_spec import (
            ColumnStringLengthAboveMaxLengthPercentCheckSpec,
        )
        from ..models.column_string_length_below_min_length_count_check_spec import (
            ColumnStringLengthBelowMinLengthCountCheckSpec,
        )
        from ..models.column_string_length_below_min_length_percent_check_spec import (
            ColumnStringLengthBelowMinLengthPercentCheckSpec,
        )
        from ..models.column_string_length_in_range_percent_check_spec import (
            ColumnStringLengthInRangePercentCheckSpec,
        )
        from ..models.column_string_match_date_regex_percent_check_spec import (
            ColumnStringMatchDateRegexPercentCheckSpec,
        )
        from ..models.column_string_match_name_regex_percent_check_spec import (
            ColumnStringMatchNameRegexPercentCheckSpec,
        )
        from ..models.column_string_match_regex_percent_check_spec import (
            ColumnStringMatchRegexPercentCheckSpec,
        )
        from ..models.column_string_max_length_check_spec import (
            ColumnStringMaxLengthCheckSpec,
        )
        from ..models.column_string_mean_length_check_spec import (
            ColumnStringMeanLengthCheckSpec,
        )
        from ..models.column_string_min_length_check_spec import (
            ColumnStringMinLengthCheckSpec,
        )
        from ..models.column_string_not_match_date_regex_count_check_spec import (
            ColumnStringNotMatchDateRegexCountCheckSpec,
        )
        from ..models.column_string_not_match_regex_count_check_spec import (
            ColumnStringNotMatchRegexCountCheckSpec,
        )
        from ..models.column_string_null_placeholder_count_check_spec import (
            ColumnStringNullPlaceholderCountCheckSpec,
        )
        from ..models.column_string_null_placeholder_percent_check_spec import (
            ColumnStringNullPlaceholderPercentCheckSpec,
        )
        from ..models.column_string_parsable_to_float_percent_check_spec import (
            ColumnStringParsableToFloatPercentCheckSpec,
        )
        from ..models.column_string_parsable_to_integer_percent_check_spec import (
            ColumnStringParsableToIntegerPercentCheckSpec,
        )
        from ..models.column_string_surrounded_by_whitespace_count_check_spec import (
            ColumnStringSurroundedByWhitespaceCountCheckSpec,
        )
        from ..models.column_string_surrounded_by_whitespace_percent_check_spec import (
            ColumnStringSurroundedByWhitespacePercentCheckSpec,
        )
        from ..models.column_string_valid_country_code_percent_check_spec import (
            ColumnStringValidCountryCodePercentCheckSpec,
        )
        from ..models.column_string_valid_currency_code_percent_check_spec import (
            ColumnStringValidCurrencyCodePercentCheckSpec,
        )
        from ..models.column_string_valid_dates_percent_check_spec import (
            ColumnStringValidDatesPercentCheckSpec,
        )
        from ..models.column_string_valid_uuid_percent_check_spec import (
            ColumnStringValidUuidPercentCheckSpec,
        )
        from ..models.column_string_value_in_set_percent_check_spec import (
            ColumnStringValueInSetPercentCheckSpec,
        )
        from ..models.column_string_whitespace_count_check_spec import (
            ColumnStringWhitespaceCountCheckSpec,
        )
        from ..models.column_string_whitespace_percent_check_spec import (
            ColumnStringWhitespacePercentCheckSpec,
        )

        d = src_dict.copy()
        _monthly_string_max_length = d.pop("monthly_string_max_length", UNSET)
        monthly_string_max_length: Union[Unset, ColumnStringMaxLengthCheckSpec]
        if isinstance(_monthly_string_max_length, Unset):
            monthly_string_max_length = UNSET
        else:
            monthly_string_max_length = ColumnStringMaxLengthCheckSpec.from_dict(
                _monthly_string_max_length
            )

        _monthly_string_min_length = d.pop("monthly_string_min_length", UNSET)
        monthly_string_min_length: Union[Unset, ColumnStringMinLengthCheckSpec]
        if isinstance(_monthly_string_min_length, Unset):
            monthly_string_min_length = UNSET
        else:
            monthly_string_min_length = ColumnStringMinLengthCheckSpec.from_dict(
                _monthly_string_min_length
            )

        _monthly_string_mean_length = d.pop("monthly_string_mean_length", UNSET)
        monthly_string_mean_length: Union[Unset, ColumnStringMeanLengthCheckSpec]
        if isinstance(_monthly_string_mean_length, Unset):
            monthly_string_mean_length = UNSET
        else:
            monthly_string_mean_length = ColumnStringMeanLengthCheckSpec.from_dict(
                _monthly_string_mean_length
            )

        _monthly_string_length_below_min_length_count = d.pop(
            "monthly_string_length_below_min_length_count", UNSET
        )
        monthly_string_length_below_min_length_count: Union[
            Unset, ColumnStringLengthBelowMinLengthCountCheckSpec
        ]
        if isinstance(_monthly_string_length_below_min_length_count, Unset):
            monthly_string_length_below_min_length_count = UNSET
        else:
            monthly_string_length_below_min_length_count = (
                ColumnStringLengthBelowMinLengthCountCheckSpec.from_dict(
                    _monthly_string_length_below_min_length_count
                )
            )

        _monthly_string_length_below_min_length_percent = d.pop(
            "monthly_string_length_below_min_length_percent", UNSET
        )
        monthly_string_length_below_min_length_percent: Union[
            Unset, ColumnStringLengthBelowMinLengthPercentCheckSpec
        ]
        if isinstance(_monthly_string_length_below_min_length_percent, Unset):
            monthly_string_length_below_min_length_percent = UNSET
        else:
            monthly_string_length_below_min_length_percent = (
                ColumnStringLengthBelowMinLengthPercentCheckSpec.from_dict(
                    _monthly_string_length_below_min_length_percent
                )
            )

        _monthly_string_length_above_max_length_count = d.pop(
            "monthly_string_length_above_max_length_count", UNSET
        )
        monthly_string_length_above_max_length_count: Union[
            Unset, ColumnStringLengthAboveMaxLengthCountCheckSpec
        ]
        if isinstance(_monthly_string_length_above_max_length_count, Unset):
            monthly_string_length_above_max_length_count = UNSET
        else:
            monthly_string_length_above_max_length_count = (
                ColumnStringLengthAboveMaxLengthCountCheckSpec.from_dict(
                    _monthly_string_length_above_max_length_count
                )
            )

        _monthly_string_length_above_max_length_percent = d.pop(
            "monthly_string_length_above_max_length_percent", UNSET
        )
        monthly_string_length_above_max_length_percent: Union[
            Unset, ColumnStringLengthAboveMaxLengthPercentCheckSpec
        ]
        if isinstance(_monthly_string_length_above_max_length_percent, Unset):
            monthly_string_length_above_max_length_percent = UNSET
        else:
            monthly_string_length_above_max_length_percent = (
                ColumnStringLengthAboveMaxLengthPercentCheckSpec.from_dict(
                    _monthly_string_length_above_max_length_percent
                )
            )

        _monthly_string_length_in_range_percent = d.pop(
            "monthly_string_length_in_range_percent", UNSET
        )
        monthly_string_length_in_range_percent: Union[
            Unset, ColumnStringLengthInRangePercentCheckSpec
        ]
        if isinstance(_monthly_string_length_in_range_percent, Unset):
            monthly_string_length_in_range_percent = UNSET
        else:
            monthly_string_length_in_range_percent = (
                ColumnStringLengthInRangePercentCheckSpec.from_dict(
                    _monthly_string_length_in_range_percent
                )
            )

        _monthly_string_empty_count = d.pop("monthly_string_empty_count", UNSET)
        monthly_string_empty_count: Union[Unset, ColumnStringEmptyCountCheckSpec]
        if isinstance(_monthly_string_empty_count, Unset):
            monthly_string_empty_count = UNSET
        else:
            monthly_string_empty_count = ColumnStringEmptyCountCheckSpec.from_dict(
                _monthly_string_empty_count
            )

        _monthly_string_empty_percent = d.pop("monthly_string_empty_percent", UNSET)
        monthly_string_empty_percent: Union[Unset, ColumnStringEmptyPercentCheckSpec]
        if isinstance(_monthly_string_empty_percent, Unset):
            monthly_string_empty_percent = UNSET
        else:
            monthly_string_empty_percent = ColumnStringEmptyPercentCheckSpec.from_dict(
                _monthly_string_empty_percent
            )

        _monthly_string_valid_dates_percent = d.pop(
            "monthly_string_valid_dates_percent", UNSET
        )
        monthly_string_valid_dates_percent: Union[
            Unset, ColumnStringValidDatesPercentCheckSpec
        ]
        if isinstance(_monthly_string_valid_dates_percent, Unset):
            monthly_string_valid_dates_percent = UNSET
        else:
            monthly_string_valid_dates_percent = (
                ColumnStringValidDatesPercentCheckSpec.from_dict(
                    _monthly_string_valid_dates_percent
                )
            )

        _monthly_string_whitespace_count = d.pop(
            "monthly_string_whitespace_count", UNSET
        )
        monthly_string_whitespace_count: Union[
            Unset, ColumnStringWhitespaceCountCheckSpec
        ]
        if isinstance(_monthly_string_whitespace_count, Unset):
            monthly_string_whitespace_count = UNSET
        else:
            monthly_string_whitespace_count = (
                ColumnStringWhitespaceCountCheckSpec.from_dict(
                    _monthly_string_whitespace_count
                )
            )

        _monthly_string_whitespace_percent = d.pop(
            "monthly_string_whitespace_percent", UNSET
        )
        monthly_string_whitespace_percent: Union[
            Unset, ColumnStringWhitespacePercentCheckSpec
        ]
        if isinstance(_monthly_string_whitespace_percent, Unset):
            monthly_string_whitespace_percent = UNSET
        else:
            monthly_string_whitespace_percent = (
                ColumnStringWhitespacePercentCheckSpec.from_dict(
                    _monthly_string_whitespace_percent
                )
            )

        _monthly_string_surrounded_by_whitespace_count = d.pop(
            "monthly_string_surrounded_by_whitespace_count", UNSET
        )
        monthly_string_surrounded_by_whitespace_count: Union[
            Unset, ColumnStringSurroundedByWhitespaceCountCheckSpec
        ]
        if isinstance(_monthly_string_surrounded_by_whitespace_count, Unset):
            monthly_string_surrounded_by_whitespace_count = UNSET
        else:
            monthly_string_surrounded_by_whitespace_count = (
                ColumnStringSurroundedByWhitespaceCountCheckSpec.from_dict(
                    _monthly_string_surrounded_by_whitespace_count
                )
            )

        _monthly_string_surrounded_by_whitespace_percent = d.pop(
            "monthly_string_surrounded_by_whitespace_percent", UNSET
        )
        monthly_string_surrounded_by_whitespace_percent: Union[
            Unset, ColumnStringSurroundedByWhitespacePercentCheckSpec
        ]
        if isinstance(_monthly_string_surrounded_by_whitespace_percent, Unset):
            monthly_string_surrounded_by_whitespace_percent = UNSET
        else:
            monthly_string_surrounded_by_whitespace_percent = (
                ColumnStringSurroundedByWhitespacePercentCheckSpec.from_dict(
                    _monthly_string_surrounded_by_whitespace_percent
                )
            )

        _monthly_string_null_placeholder_count = d.pop(
            "monthly_string_null_placeholder_count", UNSET
        )
        monthly_string_null_placeholder_count: Union[
            Unset, ColumnStringNullPlaceholderCountCheckSpec
        ]
        if isinstance(_monthly_string_null_placeholder_count, Unset):
            monthly_string_null_placeholder_count = UNSET
        else:
            monthly_string_null_placeholder_count = (
                ColumnStringNullPlaceholderCountCheckSpec.from_dict(
                    _monthly_string_null_placeholder_count
                )
            )

        _monthly_string_null_placeholder_percent = d.pop(
            "monthly_string_null_placeholder_percent", UNSET
        )
        monthly_string_null_placeholder_percent: Union[
            Unset, ColumnStringNullPlaceholderPercentCheckSpec
        ]
        if isinstance(_monthly_string_null_placeholder_percent, Unset):
            monthly_string_null_placeholder_percent = UNSET
        else:
            monthly_string_null_placeholder_percent = (
                ColumnStringNullPlaceholderPercentCheckSpec.from_dict(
                    _monthly_string_null_placeholder_percent
                )
            )

        _monthly_string_boolean_placeholder_percent = d.pop(
            "monthly_string_boolean_placeholder_percent", UNSET
        )
        monthly_string_boolean_placeholder_percent: Union[
            Unset, ColumnStringBooleanPlaceholderPercentCheckSpec
        ]
        if isinstance(_monthly_string_boolean_placeholder_percent, Unset):
            monthly_string_boolean_placeholder_percent = UNSET
        else:
            monthly_string_boolean_placeholder_percent = (
                ColumnStringBooleanPlaceholderPercentCheckSpec.from_dict(
                    _monthly_string_boolean_placeholder_percent
                )
            )

        _monthly_string_parsable_to_integer_percent = d.pop(
            "monthly_string_parsable_to_integer_percent", UNSET
        )
        monthly_string_parsable_to_integer_percent: Union[
            Unset, ColumnStringParsableToIntegerPercentCheckSpec
        ]
        if isinstance(_monthly_string_parsable_to_integer_percent, Unset):
            monthly_string_parsable_to_integer_percent = UNSET
        else:
            monthly_string_parsable_to_integer_percent = (
                ColumnStringParsableToIntegerPercentCheckSpec.from_dict(
                    _monthly_string_parsable_to_integer_percent
                )
            )

        _monthly_string_parsable_to_float_percent = d.pop(
            "monthly_string_parsable_to_float_percent", UNSET
        )
        monthly_string_parsable_to_float_percent: Union[
            Unset, ColumnStringParsableToFloatPercentCheckSpec
        ]
        if isinstance(_monthly_string_parsable_to_float_percent, Unset):
            monthly_string_parsable_to_float_percent = UNSET
        else:
            monthly_string_parsable_to_float_percent = (
                ColumnStringParsableToFloatPercentCheckSpec.from_dict(
                    _monthly_string_parsable_to_float_percent
                )
            )

        _monthly_expected_strings_in_use_count = d.pop(
            "monthly_expected_strings_in_use_count", UNSET
        )
        monthly_expected_strings_in_use_count: Union[
            Unset, ColumnExpectedStringsInUseCountCheckSpec
        ]
        if isinstance(_monthly_expected_strings_in_use_count, Unset):
            monthly_expected_strings_in_use_count = UNSET
        else:
            monthly_expected_strings_in_use_count = (
                ColumnExpectedStringsInUseCountCheckSpec.from_dict(
                    _monthly_expected_strings_in_use_count
                )
            )

        _monthly_string_value_in_set_percent = d.pop(
            "monthly_string_value_in_set_percent", UNSET
        )
        monthly_string_value_in_set_percent: Union[
            Unset, ColumnStringValueInSetPercentCheckSpec
        ]
        if isinstance(_monthly_string_value_in_set_percent, Unset):
            monthly_string_value_in_set_percent = UNSET
        else:
            monthly_string_value_in_set_percent = (
                ColumnStringValueInSetPercentCheckSpec.from_dict(
                    _monthly_string_value_in_set_percent
                )
            )

        _monthly_string_valid_country_code_percent = d.pop(
            "monthly_string_valid_country_code_percent", UNSET
        )
        monthly_string_valid_country_code_percent: Union[
            Unset, ColumnStringValidCountryCodePercentCheckSpec
        ]
        if isinstance(_monthly_string_valid_country_code_percent, Unset):
            monthly_string_valid_country_code_percent = UNSET
        else:
            monthly_string_valid_country_code_percent = (
                ColumnStringValidCountryCodePercentCheckSpec.from_dict(
                    _monthly_string_valid_country_code_percent
                )
            )

        _monthly_string_valid_currency_code_percent = d.pop(
            "monthly_string_valid_currency_code_percent", UNSET
        )
        monthly_string_valid_currency_code_percent: Union[
            Unset, ColumnStringValidCurrencyCodePercentCheckSpec
        ]
        if isinstance(_monthly_string_valid_currency_code_percent, Unset):
            monthly_string_valid_currency_code_percent = UNSET
        else:
            monthly_string_valid_currency_code_percent = (
                ColumnStringValidCurrencyCodePercentCheckSpec.from_dict(
                    _monthly_string_valid_currency_code_percent
                )
            )

        _monthly_string_invalid_email_count = d.pop(
            "monthly_string_invalid_email_count", UNSET
        )
        monthly_string_invalid_email_count: Union[
            Unset, ColumnStringInvalidEmailCountCheckSpec
        ]
        if isinstance(_monthly_string_invalid_email_count, Unset):
            monthly_string_invalid_email_count = UNSET
        else:
            monthly_string_invalid_email_count = (
                ColumnStringInvalidEmailCountCheckSpec.from_dict(
                    _monthly_string_invalid_email_count
                )
            )

        _monthly_string_invalid_uuid_count = d.pop(
            "monthly_string_invalid_uuid_count", UNSET
        )
        monthly_string_invalid_uuid_count: Union[
            Unset, ColumnStringInvalidUuidCountCheckSpec
        ]
        if isinstance(_monthly_string_invalid_uuid_count, Unset):
            monthly_string_invalid_uuid_count = UNSET
        else:
            monthly_string_invalid_uuid_count = (
                ColumnStringInvalidUuidCountCheckSpec.from_dict(
                    _monthly_string_invalid_uuid_count
                )
            )

        _monthly_string_valid_uuid_percent = d.pop(
            "monthly_string_valid_uuid_percent", UNSET
        )
        monthly_string_valid_uuid_percent: Union[
            Unset, ColumnStringValidUuidPercentCheckSpec
        ]
        if isinstance(_monthly_string_valid_uuid_percent, Unset):
            monthly_string_valid_uuid_percent = UNSET
        else:
            monthly_string_valid_uuid_percent = (
                ColumnStringValidUuidPercentCheckSpec.from_dict(
                    _monthly_string_valid_uuid_percent
                )
            )

        _monthly_string_invalid_ip4_address_count = d.pop(
            "monthly_string_invalid_ip4_address_count", UNSET
        )
        monthly_string_invalid_ip4_address_count: Union[
            Unset, ColumnStringInvalidIp4AddressCountCheckSpec
        ]
        if isinstance(_monthly_string_invalid_ip4_address_count, Unset):
            monthly_string_invalid_ip4_address_count = UNSET
        else:
            monthly_string_invalid_ip4_address_count = (
                ColumnStringInvalidIp4AddressCountCheckSpec.from_dict(
                    _monthly_string_invalid_ip4_address_count
                )
            )

        _monthly_string_invalid_ip6_address_count = d.pop(
            "monthly_string_invalid_ip6_address_count", UNSET
        )
        monthly_string_invalid_ip6_address_count: Union[
            Unset, ColumnStringInvalidIp6AddressCountCheckSpec
        ]
        if isinstance(_monthly_string_invalid_ip6_address_count, Unset):
            monthly_string_invalid_ip6_address_count = UNSET
        else:
            monthly_string_invalid_ip6_address_count = (
                ColumnStringInvalidIp6AddressCountCheckSpec.from_dict(
                    _monthly_string_invalid_ip6_address_count
                )
            )

        _monthly_string_not_match_regex_count = d.pop(
            "monthly_string_not_match_regex_count", UNSET
        )
        monthly_string_not_match_regex_count: Union[
            Unset, ColumnStringNotMatchRegexCountCheckSpec
        ]
        if isinstance(_monthly_string_not_match_regex_count, Unset):
            monthly_string_not_match_regex_count = UNSET
        else:
            monthly_string_not_match_regex_count = (
                ColumnStringNotMatchRegexCountCheckSpec.from_dict(
                    _monthly_string_not_match_regex_count
                )
            )

        _monthly_string_match_regex_percent = d.pop(
            "monthly_string_match_regex_percent", UNSET
        )
        monthly_string_match_regex_percent: Union[
            Unset, ColumnStringMatchRegexPercentCheckSpec
        ]
        if isinstance(_monthly_string_match_regex_percent, Unset):
            monthly_string_match_regex_percent = UNSET
        else:
            monthly_string_match_regex_percent = (
                ColumnStringMatchRegexPercentCheckSpec.from_dict(
                    _monthly_string_match_regex_percent
                )
            )

        _monthly_string_not_match_date_regex_count = d.pop(
            "monthly_string_not_match_date_regex_count", UNSET
        )
        monthly_string_not_match_date_regex_count: Union[
            Unset, ColumnStringNotMatchDateRegexCountCheckSpec
        ]
        if isinstance(_monthly_string_not_match_date_regex_count, Unset):
            monthly_string_not_match_date_regex_count = UNSET
        else:
            monthly_string_not_match_date_regex_count = (
                ColumnStringNotMatchDateRegexCountCheckSpec.from_dict(
                    _monthly_string_not_match_date_regex_count
                )
            )

        _monthly_string_match_date_regex_percent = d.pop(
            "monthly_string_match_date_regex_percent", UNSET
        )
        monthly_string_match_date_regex_percent: Union[
            Unset, ColumnStringMatchDateRegexPercentCheckSpec
        ]
        if isinstance(_monthly_string_match_date_regex_percent, Unset):
            monthly_string_match_date_regex_percent = UNSET
        else:
            monthly_string_match_date_regex_percent = (
                ColumnStringMatchDateRegexPercentCheckSpec.from_dict(
                    _monthly_string_match_date_regex_percent
                )
            )

        _monthly_string_match_name_regex_percent = d.pop(
            "monthly_string_match_name_regex_percent", UNSET
        )
        monthly_string_match_name_regex_percent: Union[
            Unset, ColumnStringMatchNameRegexPercentCheckSpec
        ]
        if isinstance(_monthly_string_match_name_regex_percent, Unset):
            monthly_string_match_name_regex_percent = UNSET
        else:
            monthly_string_match_name_regex_percent = (
                ColumnStringMatchNameRegexPercentCheckSpec.from_dict(
                    _monthly_string_match_name_regex_percent
                )
            )

        _monthly_expected_strings_in_top_values_count = d.pop(
            "monthly_expected_strings_in_top_values_count", UNSET
        )
        monthly_expected_strings_in_top_values_count: Union[
            Unset, ColumnExpectedStringsInTopValuesCountCheckSpec
        ]
        if isinstance(_monthly_expected_strings_in_top_values_count, Unset):
            monthly_expected_strings_in_top_values_count = UNSET
        else:
            monthly_expected_strings_in_top_values_count = (
                ColumnExpectedStringsInTopValuesCountCheckSpec.from_dict(
                    _monthly_expected_strings_in_top_values_count
                )
            )

        _monthly_string_datatype_detected = d.pop(
            "monthly_string_datatype_detected", UNSET
        )
        monthly_string_datatype_detected: Union[
            Unset, ColumnStringDatatypeDetectedCheckSpec
        ]
        if isinstance(_monthly_string_datatype_detected, Unset):
            monthly_string_datatype_detected = UNSET
        else:
            monthly_string_datatype_detected = (
                ColumnStringDatatypeDetectedCheckSpec.from_dict(
                    _monthly_string_datatype_detected
                )
            )

        column_strings_monthly_recurring_checks_spec = cls(
            monthly_string_max_length=monthly_string_max_length,
            monthly_string_min_length=monthly_string_min_length,
            monthly_string_mean_length=monthly_string_mean_length,
            monthly_string_length_below_min_length_count=monthly_string_length_below_min_length_count,
            monthly_string_length_below_min_length_percent=monthly_string_length_below_min_length_percent,
            monthly_string_length_above_max_length_count=monthly_string_length_above_max_length_count,
            monthly_string_length_above_max_length_percent=monthly_string_length_above_max_length_percent,
            monthly_string_length_in_range_percent=monthly_string_length_in_range_percent,
            monthly_string_empty_count=monthly_string_empty_count,
            monthly_string_empty_percent=monthly_string_empty_percent,
            monthly_string_valid_dates_percent=monthly_string_valid_dates_percent,
            monthly_string_whitespace_count=monthly_string_whitespace_count,
            monthly_string_whitespace_percent=monthly_string_whitespace_percent,
            monthly_string_surrounded_by_whitespace_count=monthly_string_surrounded_by_whitespace_count,
            monthly_string_surrounded_by_whitespace_percent=monthly_string_surrounded_by_whitespace_percent,
            monthly_string_null_placeholder_count=monthly_string_null_placeholder_count,
            monthly_string_null_placeholder_percent=monthly_string_null_placeholder_percent,
            monthly_string_boolean_placeholder_percent=monthly_string_boolean_placeholder_percent,
            monthly_string_parsable_to_integer_percent=monthly_string_parsable_to_integer_percent,
            monthly_string_parsable_to_float_percent=monthly_string_parsable_to_float_percent,
            monthly_expected_strings_in_use_count=monthly_expected_strings_in_use_count,
            monthly_string_value_in_set_percent=monthly_string_value_in_set_percent,
            monthly_string_valid_country_code_percent=monthly_string_valid_country_code_percent,
            monthly_string_valid_currency_code_percent=monthly_string_valid_currency_code_percent,
            monthly_string_invalid_email_count=monthly_string_invalid_email_count,
            monthly_string_invalid_uuid_count=monthly_string_invalid_uuid_count,
            monthly_string_valid_uuid_percent=monthly_string_valid_uuid_percent,
            monthly_string_invalid_ip4_address_count=monthly_string_invalid_ip4_address_count,
            monthly_string_invalid_ip6_address_count=monthly_string_invalid_ip6_address_count,
            monthly_string_not_match_regex_count=monthly_string_not_match_regex_count,
            monthly_string_match_regex_percent=monthly_string_match_regex_percent,
            monthly_string_not_match_date_regex_count=monthly_string_not_match_date_regex_count,
            monthly_string_match_date_regex_percent=monthly_string_match_date_regex_percent,
            monthly_string_match_name_regex_percent=monthly_string_match_name_regex_percent,
            monthly_expected_strings_in_top_values_count=monthly_expected_strings_in_top_values_count,
            monthly_string_datatype_detected=monthly_string_datatype_detected,
        )

        column_strings_monthly_recurring_checks_spec.additional_properties = d
        return column_strings_monthly_recurring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_integrity_foreign_key_match_percent_check_spec import (
        ColumnIntegrityForeignKeyMatchPercentCheckSpec,
    )
    from ..models.column_integrity_foreign_key_not_match_count_check_spec import (
        ColumnIntegrityForeignKeyNotMatchCountCheckSpec,
    )


T = TypeVar("T", bound="ColumnIntegrityMonthlyPartitionedChecksSpec")


@attr.s(auto_attribs=True)
class ColumnIntegrityMonthlyPartitionedChecksSpec:
    """
    Attributes:
        monthly_partition_foreign_key_not_match_count (Union[Unset, ColumnIntegrityForeignKeyNotMatchCountCheckSpec]):
        monthly_partition_foreign_key_match_percent (Union[Unset, ColumnIntegrityForeignKeyMatchPercentCheckSpec]):
    """

    monthly_partition_foreign_key_not_match_count: Union[
        Unset, "ColumnIntegrityForeignKeyNotMatchCountCheckSpec"
    ] = UNSET
    monthly_partition_foreign_key_match_percent: Union[
        Unset, "ColumnIntegrityForeignKeyMatchPercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        monthly_partition_foreign_key_not_match_count: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_foreign_key_not_match_count, Unset):
            monthly_partition_foreign_key_not_match_count = (
                self.monthly_partition_foreign_key_not_match_count.to_dict()
            )

        monthly_partition_foreign_key_match_percent: Union[
            Unset, Dict[str, Any]
        ] = UNSET
        if not isinstance(self.monthly_partition_foreign_key_match_percent, Unset):
            monthly_partition_foreign_key_match_percent = (
                self.monthly_partition_foreign_key_match_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if monthly_partition_foreign_key_not_match_count is not UNSET:
            field_dict[
                "monthly_partition_foreign_key_not_match_count"
            ] = monthly_partition_foreign_key_not_match_count
        if monthly_partition_foreign_key_match_percent is not UNSET:
            field_dict[
                "monthly_partition_foreign_key_match_percent"
            ] = monthly_partition_foreign_key_match_percent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_integrity_foreign_key_match_percent_check_spec import (
            ColumnIntegrityForeignKeyMatchPercentCheckSpec,
        )
        from ..models.column_integrity_foreign_key_not_match_count_check_spec import (
            ColumnIntegrityForeignKeyNotMatchCountCheckSpec,
        )

        d = src_dict.copy()
        _monthly_partition_foreign_key_not_match_count = d.pop(
            "monthly_partition_foreign_key_not_match_count", UNSET
        )
        monthly_partition_foreign_key_not_match_count: Union[
            Unset, ColumnIntegrityForeignKeyNotMatchCountCheckSpec
        ]
        if isinstance(_monthly_partition_foreign_key_not_match_count, Unset):
            monthly_partition_foreign_key_not_match_count = UNSET
        else:
            monthly_partition_foreign_key_not_match_count = (
                ColumnIntegrityForeignKeyNotMatchCountCheckSpec.from_dict(
                    _monthly_partition_foreign_key_not_match_count
                )
            )

        _monthly_partition_foreign_key_match_percent = d.pop(
            "monthly_partition_foreign_key_match_percent", UNSET
        )
        monthly_partition_foreign_key_match_percent: Union[
            Unset, ColumnIntegrityForeignKeyMatchPercentCheckSpec
        ]
        if isinstance(_monthly_partition_foreign_key_match_percent, Unset):
            monthly_partition_foreign_key_match_percent = UNSET
        else:
            monthly_partition_foreign_key_match_percent = (
                ColumnIntegrityForeignKeyMatchPercentCheckSpec.from_dict(
                    _monthly_partition_foreign_key_match_percent
                )
            )

        column_integrity_monthly_partitioned_checks_spec = cls(
            monthly_partition_foreign_key_not_match_count=monthly_partition_foreign_key_not_match_count,
            monthly_partition_foreign_key_match_percent=monthly_partition_foreign_key_match_percent,
        )

        column_integrity_monthly_partitioned_checks_spec.additional_properties = d
        return column_integrity_monthly_partitioned_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.synchronize_root_folder_parameters import (
        SynchronizeRootFolderParameters,
    )


T = TypeVar("T", bound="SynchronizeRootFolderDqoQueueJobParameters")


@attr.s(auto_attribs=True)
class SynchronizeRootFolderDqoQueueJobParameters:
    """
    Attributes:
        synchronization_parameter (Union[Unset, SynchronizeRootFolderParameters]):
    """

    synchronization_parameter: Union[Unset, "SynchronizeRootFolderParameters"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        synchronization_parameter: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.synchronization_parameter, Unset):
            synchronization_parameter = self.synchronization_parameter.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if synchronization_parameter is not UNSET:
            field_dict["synchronizationParameter"] = synchronization_parameter

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.synchronize_root_folder_parameters import (
            SynchronizeRootFolderParameters,
        )

        d = src_dict.copy()
        _synchronization_parameter = d.pop("synchronizationParameter", UNSET)
        synchronization_parameter: Union[Unset, SynchronizeRootFolderParameters]
        if isinstance(_synchronization_parameter, Unset):
            synchronization_parameter = UNSET
        else:
            synchronization_parameter = SynchronizeRootFolderParameters.from_dict(
                _synchronization_parameter
            )

        synchronize_root_folder_dqo_queue_job_parameters = cls(
            synchronization_parameter=synchronization_parameter,
        )

        synchronize_root_folder_dqo_queue_job_parameters.additional_properties = d
        return synchronize_root_folder_dqo_queue_job_parameters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.data_grouping_configuration_spec import DataGroupingConfigurationSpec


T = TypeVar("T", bound="DataGroupingConfigurationTrimmedModel")


@attr.s(auto_attribs=True)
class DataGroupingConfigurationTrimmedModel:
    """Data grouping configuration model with trimmed path

    Attributes:
        data_grouping_configuration_name (Union[Unset, str]): Data grouping configuration name.
        spec (Union[Unset, DataGroupingConfigurationSpec]):
    """

    data_grouping_configuration_name: Union[Unset, str] = UNSET
    spec: Union[Unset, "DataGroupingConfigurationSpec"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        data_grouping_configuration_name = self.data_grouping_configuration_name
        spec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.spec, Unset):
            spec = self.spec.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if data_grouping_configuration_name is not UNSET:
            field_dict[
                "data_grouping_configuration_name"
            ] = data_grouping_configuration_name
        if spec is not UNSET:
            field_dict["spec"] = spec

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.data_grouping_configuration_spec import (
            DataGroupingConfigurationSpec,
        )

        d = src_dict.copy()
        data_grouping_configuration_name = d.pop(
            "data_grouping_configuration_name", UNSET
        )

        _spec = d.pop("spec", UNSET)
        spec: Union[Unset, DataGroupingConfigurationSpec]
        if isinstance(_spec, Unset):
            spec = UNSET
        else:
            spec = DataGroupingConfigurationSpec.from_dict(_spec)

        data_grouping_configuration_trimmed_model = cls(
            data_grouping_configuration_name=data_grouping_configuration_name,
            spec=spec,
        )

        data_grouping_configuration_trimmed_model.additional_properties = d
        return data_grouping_configuration_trimmed_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
